@@ -113,11 +113,18 @@ fixSymfonyCacheRights() {
 fixCentreonCronPermissions() {
   # MON-146883
   # Override permissions for cron scripts
-  chmod 0755 \
-    /usr/share/centreon/cron/outdated-token-removal.php
+  chmod 0755 /usr/share/centreon/cron/outdated-token-removal.php
+  chown -R centreon:centreon /usr/share/centreon/cron/outdated-token-removal.php
 
-  chown -R centreon:centreon \
-    /usr/share/centreon/cron/outdated-token-removal.php
+  # Update log file permissions which has been potentially created by centreon user
+  APP_LOG_FILE="/var/log/centreon/centreon-web.log"
+  if [ -f "$APP_LOG_FILE" ]; then
+    if [ "$1" = "rpm" ]; then
+      chown apache:apache "$APP_LOG_FILE"
+    else
+      chown www-data:www-data "$APP_LOG_FILE"
+    fi
+  fi
 }
 
 package_type="rpm"
@@ -152,7 +159,7 @@ case "$action" in
     manageApacheAndPhpFpm $package_type
     fixSymfonyCacheRights $package_type
     rebuildSymfonyCache $package_type
-    fixCentreonCronPermissions
+    fixCentreonCronPermissions $package_type
     ;;
   *)
     # $1 == version being installed
