@@ -143,6 +143,25 @@ class Assertion
         }
     }
 
+    /**
+     * Assert that a date is bigger as a given limit.
+     *
+     * @param \DateTimeInterface $value
+     * @param \DateTimeInterface $minDate
+     * @param string|null $propertyPath
+     *
+     * @throws \Assert\AssertionFailedException
+     */
+    public static function minDate(
+        \DateTimeInterface $value,
+        \DateTimeInterface $minDate,
+        ?string $propertyPath = null
+    ): void {
+        if ($value->getTimestamp() < $minDate->getTimestamp()) {
+            throw AssertionException::maxDate($value, $minDate, $propertyPath);
+        }
+    }
+
     /**
      * Determines if the value is greater or equal than given limit.
      *
@@ -298,6 +317,121 @@ class Assertion
         }
     }
 
+    /**
+     * @param object $value
+     * @param class-string $className
+     * @param string|null $propertyPath
+     *
+     * @throws \Assert\AssertionFailedException
+     */
+    public static function isInstanceOf(mixed $value, string $className, ?string $propertyPath = null): void
+    {
+        if (! ($value instanceof $className)) {
+            throw AssertionException::badInstanceOfObject(
+                get_debug_type($value),
+                $className,
+                $propertyPath
+            );
+        }
+    }
+
+    /**
+     * Assert that string value is a valid JSON string.
+     *
+     * @param string $value Value to test
+     * @param string|null $propertyPath Property's path (ex: Host::name)
+     *
+     * @throws \Assert\AssertionFailedException
+     */
+    public static function jsonString(string $value, ?string $propertyPath = null): void
+    {
+        try {
+            json_decode($value, true, 512, JSON_THROW_ON_ERROR);
+        } catch (\JsonException) {
+            throw AssertionException::invalidJsonString($propertyPath);
+        }
+    }
+
+    /**
+     * Assert that the value can be encoded to a valid JSON string.
+     *
+     * @param mixed $value Value to test
+     * @param string|null $propertyPath Property's path (ex: Host::name)
+     * @param int|null $maxLength
+     *
+     * @throws AssertionException
+     */
+    public static function jsonEncodable(mixed $value, ?string $propertyPath = null, ?int $maxLength = null): void
+    {
+        try {
+            $json = json_encode($value, JSON_THROW_ON_ERROR | JSON_PRESERVE_ZERO_FRACTION);
+            if (null !== $maxLength) {
+                $length = \mb_strlen($json, 'utf8');
+                if ($length > $maxLength) {
+                    throw AssertionException::maxLength('<JSON>', $length, $maxLength, $propertyPath);
+                }
+            }
+        } catch (\JsonException) {
+            throw AssertionException::notJsonEncodable($propertyPath);
+        }
+    }
+
+    /**
+     * @param string $value Value to test
+     * @param string $unauthorizedCharacters List of non-authorized characters
+     * @param string|null $propertyPath Property's path (ex: Host::name)
+     *
+     * @throws \Assert\AssertionFailedException
+     */
+    public static function unauthorizedCharacters(
+        string $value,
+        string $unauthorizedCharacters,
+        ?string $propertyPath = null
+    ): void {
+        if ($unauthorizedCharacters !== '' && $value !== '') {
+            $unauthorizedCharactersFound = array_unique(
+                array_intersect(
+                    mb_str_split($value),
+                    mb_str_split($unauthorizedCharacters)
+                )
+            );
+            if ($unauthorizedCharactersFound !== []) {
+                throw AssertionException::unauthorizedCharacters(
+                    $value,
+                    implode('', $unauthorizedCharactersFound),
+                    $propertyPath
+                );
+            }
+        }
+    }
+
+    /**
+     * Validate that the values of array are correct type
+     *
+     * @param 'string'|'float'|'int' $type
+     * @param array<mixed> $values
+     *
+     * @throws AssertionException
+     */
+    public static function arrayOfTypeOrNull(string $type, array $values, string $propertyPath): void
+    {
+        try {
+            switch ($type) {
+                case 'string':
+                    (fn (?string ...$items): array => $items)(...$values);
+                    break;
+                case 'float':
+                    (fn (?float ...$items): array => $items)(...$values);
+                    break;
+                case 'int':
+                    (fn (?int ...$items): array => $items)(...$values);
+                    break;
+            }
+        } catch(\TypeError) {
+            throw AssertionException::invalidTypeInArray($type, $propertyPath);
+        }
+    }
+
     /**
      * Make a string version of a value.
      *
