@@ -46,24 +46,25 @@ class Installer extends Widget
     protected function installConfiguration()
     {
         $query = 'INSERT INTO widget_models '
-            . '(title, description, url, version, directory, author, '
+            . '(title, description, url, version, is_internal, directory, author, '
             . 'email, website, keywords, thumbnail, autoRefresh) '
-            . 'VALUES (:title, :description, :url, :version, :directory, :author, '
+            . 'VALUES (:title, :description, :url, :version, :is_internal, :directory, :author, '
             . ':email, :website, :keywords, :thumbnail, :autoRefresh) ';
 
         $sth = $this->services->get('configuration_db')->prepare($query);
 
-        $sth->bindParam(':title', $this->widgetConfiguration['title'], \PDO::PARAM_STR);
-        $sth->bindParam(':description', $this->widgetConfiguration['description'], \PDO::PARAM_STR);
-        $sth->bindParam(':url', $this->widgetConfiguration['url'], \PDO::PARAM_STR);
-        $sth->bindParam(':version', $this->widgetConfiguration['version'], \PDO::PARAM_STR);
-        $sth->bindParam(':directory', $this->widgetConfiguration['directory'], \PDO::PARAM_STR);
-        $sth->bindParam(':author', $this->widgetConfiguration['author'], \PDO::PARAM_STR);
-        $sth->bindParam(':email', $this->widgetConfiguration['email'], \PDO::PARAM_STR);
-        $sth->bindParam(':website', $this->widgetConfiguration['website'], \PDO::PARAM_STR);
-        $sth->bindParam(':keywords', $this->widgetConfiguration['keywords'], \PDO::PARAM_STR);
-        $sth->bindParam(':thumbnail', $this->widgetConfiguration['thumbnail'], \PDO::PARAM_STR);
-        $sth->bindParam(':autoRefresh', $this->widgetConfiguration['autoRefresh'], \PDO::PARAM_INT);
+        $sth->bindValue(':title', $this->widgetConfiguration['title'], \PDO::PARAM_STR);
+        $sth->bindValue(':description', $this->widgetConfiguration['description'], \PDO::PARAM_STR);
+        $sth->bindValue(':url', $this->widgetConfiguration['url'], \PDO::PARAM_STR);
+        $sth->bindValue(':version', $this->widgetConfiguration['version'], \PDO::PARAM_STR);
+        $sth->bindValue(':is_internal', $this->widgetConfiguration['version'] === null, \PDO::PARAM_BOOL);
+        $sth->bindValue(':directory', $this->widgetConfiguration['directory'], \PDO::PARAM_STR);
+        $sth->bindValue(':author', $this->widgetConfiguration['author'], \PDO::PARAM_STR);
+        $sth->bindValue(':email', $this->widgetConfiguration['email'], \PDO::PARAM_STR);
+        $sth->bindValue(':website', $this->widgetConfiguration['website'], \PDO::PARAM_STR);
+        $sth->bindValue(':keywords', $this->widgetConfiguration['keywords'], \PDO::PARAM_STR);
+        $sth->bindValue(':thumbnail', $this->widgetConfiguration['thumbnail'], \PDO::PARAM_STR);
+        $sth->bindValue(':autoRefresh', $this->widgetConfiguration['autoRefresh'], \PDO::PARAM_INT);
 
         $sth->execute();
 
@@ -74,8 +75,6 @@ class Installer extends Widget
      * @param int $id
      *
      * @throws \Exception
-     *
-     * @return type
      */
     protected function installPreferences($id)
     {
@@ -154,8 +153,6 @@ class Installer extends Widget
     /**
      * @param int $paramId
      * @param array $preference
-     *
-     * @return type
      */
     protected function installMultipleOption($paramId, $preference)
     {
