@@ -26,6 +26,7 @@ namespace Core\HostCategory\Application\Repository;
 use Centreon\Domain\RequestParameters\Interfaces\RequestParametersInterface;
 use Core\Common\Domain\TrimmedString;
 use Core\HostCategory\Domain\Model\HostCategory;
+use Core\HostCategory\Domain\Model\HostCategoryNamesById;
 use Core\Security\AccessGroup\Domain\Model\AccessGroup;
 
 interface ReadHostCategoryRepositoryInterface
@@ -44,14 +45,14 @@ interface ReadHostCategoryRepositoryInterface
     /**
      * Find all host categories by access groups.
      *
-     * @param AccessGroup[] $accessGroups
+     * @param int[] $accessGroupIds
      * @param RequestParametersInterface|null $requestParameters
      *
      * @throws \Throwable
      *
      * @return HostCategory[]
      */
-    public function findAllByAccessGroups(array $accessGroups, ?RequestParametersInterface $requestParameters): array;
+    public function findAllByAccessGroupIds(array $accessGroupIds, ?RequestParametersInterface $requestParameters): array;
 
     /**
      * Check existence of a host category.
@@ -156,4 +157,22 @@ interface ReadHostCategoryRepositoryInterface
      * @return HostCategory[]
      */
     public function findByHostAndAccessGroups(int $hostId, array $accessGroups): array;
+
+    /**
+     * Find Host Categories names by their IDs.
+     *
+     * @param int[] $hostCategoryIds
+     *
+     * @return HostCategoryNamesById
+     */
+    public function findNames(array $hostCategoryIds): HostCategoryNamesById;
+
+    /**
+     * Determine if host categories are filtered for given access group ids.
+     *
+     * @param int[] $accessGroupIds
+     *
+     * @return bool
+     */
+    public function hasRestrictedAccessToHostCategories(array $accessGroupIds): bool;
 }
