@@ -29,12 +29,15 @@ use Centreon\Infrastructure\DatabaseConnection;
 use Centreon\Infrastructure\Repository\AbstractRepositoryDRB;
 use Centreon\Infrastructure\RequestParameters\RequestParametersTranslatorException;
 use Centreon\Infrastructure\RequestParameters\SqlRequestParametersTranslator;
+use Core\Common\Domain\TrimmedString;
 use Core\Common\Infrastructure\Repository\SqlMultipleBindTrait;
 use Core\Common\Infrastructure\RequestParameters\Normalizer\BoolToEnumNormalizer;
 use Core\Domain\Common\GeoCoords;
 use Core\Domain\Exception\InvalidGeoCoordException;
+use Core\HostCategory\Infrastructure\Repository\HostCategoryRepositoryTrait;
 use Core\HostGroup\Application\Repository\ReadHostGroupRepositoryInterface;
 use Core\HostGroup\Domain\Model\HostGroup;
+use Core\HostGroup\Domain\Model\HostGroupNamesById;
 use Core\Security\AccessGroup\Domain\Model\AccessGroup;
 use Utility\SqlConcatenator;
 
@@ -56,7 +59,7 @@ use Utility\SqlConcatenator;
  */
 class DbReadHostGroupRepository extends AbstractRepositoryDRB implements ReadHostGroupRepositoryInterface
 {
-    use SqlMultipleBindTrait;
+    use SqlMultipleBindTrait, HostCategoryRepositoryTrait, HostGroupRepositoryTrait;
 
     public function __construct(DatabaseConnection $db)
     {
@@ -66,32 +69,224 @@ class DbReadHostGroupRepository extends AbstractRepositoryDRB implements ReadHos
     /**
      * @inheritDoc
      */
-    public function findAll(?RequestParametersInterface $requestParameters): array
+    public function findNames(array $hostGroupIds): HostGroupNamesById
     {
-        $concatenator = $this->getFindHostGroupConcatenator();
+        $concatenator = new SqlConcatenator();
 
-        return $this->retrieveHostGroups($concatenator, $requestParameters);
+        $hostGroupIds = array_unique($hostGroupIds);
+
+        $concatenator->defineSelect(
+            <<<'SQL'
+                    SELECT hg.hg_id, hg.hg_name
+                    FROM `:db`.hostgroup hg
+                    WHERE hg.hg_id IN (:hostGroupIds)
+                SQL
+        );
+
+        $concatenator->storeBindValueMultiple(':hostGroupIds', $hostGroupIds, \PDO::PARAM_INT);
+        $statement = $this->db->prepare($this->translateDbName($concatenator->__toString()));
+        $concatenator->bindValuesToStatement($statement);
+        $statement->setFetchMode(\PDO::FETCH_ASSOC);
+        $statement->execute();
+
+        $names = new HostGroupNamesById();
+
+        foreach ($statement as $record) {
+            /** @var array{hg_id:int,hg_name:string} $record */
+            $names->addName(
+                $record['hg_id'],
+                new TrimmedString($record['hg_name'])
+            );
+        }
+
+        return $names;
     }
 
     /**
      * @inheritDoc
      */
-    public function findAllByAccessGroups(?RequestParametersInterface $requestParameters, array $accessGroups): array
+    public function findAll(?RequestParametersInterface $requestParameters = null): \Traversable&\Countable
     {
-        if ([] === $accessGroups) {
-            return [];
+        $request = <<<'SQL'
+            SELECT SQL_CALC_FOUND_ROWS DISTINCT
+                hg.hg_id,
+                hg.hg_name,
+                hg.hg_alias,
+                hg.hg_notes,
+                hg.hg_notes_url,
+                hg.hg_action_url,
+                hg.hg_icon_image,
+                hg.hg_map_icon_image,
+                hg.hg_rrd_retention,
+                hg.geo_coords,
+                hg.hg_comment,
+                hg.hg_activate
+            FROM `:db`.`hostgroup` hg
+            SQL;
+
+        $sqlTranslator = $requestParameters ? new SqlRequestParametersTranslator($requestParameters) : null;
+        $sqlTranslator?->setConcordanceArray([
+            'id' => 'hg.hg_id',
+            'alias' => 'hg.hg_alias',
+            'name' => 'hg.hg_name',
+            'is_activated' => 'hg.hg_activate',
+            'hostcategory.id' => 'hc.hc_id',
+            'hostcategory.name' => 'hc.hc_name',
+        ]);
+        $sqlTranslator?->addNormalizer('is_activated', new BoolToEnumNormalizer());
+
+        // Update the SQL string builder with the RequestParameters through SqlRequestParametersTranslator
+        $searchRequest = $sqlTranslator?->translateSearchParameterToSql();
+
+        // Only JOIN if search request has been provided...
+        if ($searchRequest !== null) {
+            $request .= <<<'SQL'
+                    LEFT JOIN `:db`.hostgroup_relation hgr
+                        ON hgr.hostgroup_hg_id = hg.hg_id
+                    LEFT JOIN `:db`.hostcategories_relation hcr
+                        ON hcr.host_host_id = hgr.host_host_id
+                    LEFT JOIN `:db`.hostcategories hc
+                        ON hc.hc_id = hcr.hostcategories_hc_id
+                        AND hc.level IS NULL
+                SQL;
         }
 
-        $accessGroupIds = $this->accessGroupsToIds($accessGroups);
+        $request .= $searchRequest;
 
-        if ($this->hasAccessToAllHostGroups($accessGroupIds)) {
+        // handle sort
+        $sortRequest = $sqlTranslator?->translateSortParameterToSql();
 
-            return $this->findAll($requestParameters);
+        $request .= $sortRequest !== null
+            ? $sortRequest
+            : ' ORDER BY hg.hg_name ASC';
+
+        // handle pagination
+        $request .= $sqlTranslator?->translatePaginationToSql();
+
+        // Prepare SQL + bind values
+        $statement = $this->db->prepare($this->translateDbName($request));
+        $sqlTranslator?->bindSearchValues($statement);
+
+        $statement->setFetchMode(\PDO::FETCH_ASSOC);
+        $statement->execute();
+
+        // Calculate the number of rows for the pagination.
+        $sqlTranslator?->calculateNumberOfRows($this->db);
+
+        $hostGroups = [];
+
+        foreach ($statement as $record) {
+            /** @var HostGroupResultSet $record */
+            $hostGroups[] = $this->createHostGroupFromArray($record);
         }
 
-        $concatenator = $this->getFindHostGroupConcatenator($accessGroupIds);
+        return new \ArrayIterator($hostGroups);
+    }
 
-        return $this->retrieveHostGroups($concatenator, $requestParameters);
+    /**
+     * @inheritDoc
+     */
+    public function findAllByAccessGroupIds(?RequestParametersInterface $requestParameters, array $accessGroupIds): \Traversable&\Countable
+    {
+        if ([] === $accessGroupIds) {
+            return new \ArrayIterator([]);
+        }
+
+        [$bindValues, $bindQuery] = $this->createMultipleBindQuery($accessGroupIds, ':access_group_id_');
+
+        $request = <<<'SQL'
+            SELECT SQL_CALC_FOUND_ROWS DISTINCT
+                hg.hg_id,
+                hg.hg_name,
+                hg.hg_alias,
+                hg.hg_notes,
+                hg.hg_notes_url,
+                hg.hg_action_url,
+                hg.hg_icon_image,
+                hg.hg_map_icon_image,
+                hg.hg_rrd_retention,
+                hg.geo_coords,
+                hg.hg_comment,
+                hg.hg_activate
+            FROM `:db`.`hostgroup` hg
+            INNER JOIN `:db`.acl_resources_hg_relations arhr
+                ON hg.hg_id = arhr.hg_hg_id
+            INNER JOIN `:db`.acl_resources res
+                ON arhr.acl_res_id = res.acl_res_id
+            INNER JOIN `:db`.acl_res_group_relations argr
+                ON res.acl_res_id = argr.acl_res_id
+            INNER JOIN `:db`.acl_groups ag
+                ON argr.acl_group_id = ag.acl_group_id
+            SQL;
+
+        $sqlTranslator = $requestParameters ? new SqlRequestParametersTranslator($requestParameters) : null;
+        $sqlTranslator?->setConcordanceArray([
+            'id' => 'hg.hg_id',
+            'alias' => 'hg.hg_alias',
+            'name' => 'hg.hg_name',
+            'is_activated' => 'hg.hg_activate',
+            'hostcategory.id' => 'hc.hc_id',
+            'hostcategory.name' => 'hc.hc_name',
+        ]);
+        $sqlTranslator?->addNormalizer('is_activated', new BoolToEnumNormalizer());
+
+        // Update the SQL string builder with the RequestParameters through SqlRequestParametersTranslator
+        $searchRequest = $sqlTranslator?->translateSearchParameterToSql();
+
+        // Only JOIN if search request has been provided...
+        if ($searchRequest !== null) {
+            $hostCategoryAcls = $this->generateHostCategoryAclSubRequest($accessGroupIds);
+            $request .= <<<SQL
+
+                LEFT JOIN `:db`.hostgroup_relation hgr
+                    ON hgr.hostgroup_hg_id = hg.hg_id
+                LEFT JOIN `:db`.hostcategories_relation hcr
+                    ON hcr.host_host_id = hgr.host_host_id
+                    AND hcr.hostcategories_hc_id IN ({$hostCategoryAcls})
+                LEFT JOIN `:db`.hostcategories hc
+                    ON hc.hc_id = hcr.hostcategories_hc_id
+                    AND hc.level IS NULL
+                SQL;
+        }
+
+        $request .= $searchRequest ? $searchRequest . ' AND ' : ' WHERE ';
+
+        $request .= <<<SQL
+            ag.acl_group_id IN ({$bindQuery})
+            SQL;
+
+        // handle sort
+        $sortRequest = $sqlTranslator?->translateSortParameterToSql();
+
+        $request .= $sortRequest !== null
+            ? $sortRequest
+            : ' ORDER BY hg.hg_name ASC';
+
+        // handle pagination
+        $request .= $sqlTranslator?->translatePaginationToSql();
+
+        // Prepare SQL + bind values
+        $statement = $this->db->prepare($this->translateDbName($request));
+        $sqlTranslator?->bindSearchValues($statement);
+
+        foreach ($bindValues as $key => $value) {
+            $statement->bindValue($key, $value, \PDO::PARAM_INT);
+        }
+
+        $statement->setFetchMode(\PDO::FETCH_ASSOC);
+        $statement->execute();
+
+        // Calculate the number of rows for the pagination.
+        $sqlTranslator?->calculateNumberOfRows($this->db);
+
+        $hostGroups = [];
+
+        foreach ($statement as $record) {
+            /** @var HostGroupResultSet $record */
+            $hostGroups[] = $this->createHostGroupFromArray($record);
+        }
+
+        return new \ArrayIterator($hostGroups);
     }
 
     /**
@@ -119,7 +314,7 @@ class DbReadHostGroupRepository extends AbstractRepositoryDRB implements ReadHos
 
             return $this->findOne($hostGroupId);
         }
-        $concatenator = $this->getFindHostGroupConcatenator($accessGroupIds);
+        $concatenator = $this->getFindHostGroupConcatenator(null, $accessGroupIds);
 
         return $this->retrieveHostgroup($concatenator, $hostGroupId);
     }
@@ -148,7 +343,7 @@ class DbReadHostGroupRepository extends AbstractRepositoryDRB implements ReadHos
 
             return $this->existsOne($hostGroupId);
         }
-        $concatenator = $this->getFindHostGroupConcatenator($accessGroupIds);
+        $concatenator = $this->getFindHostGroupConcatenator(null, $accessGroupIds);
 
         return $this->existsHostGroup($concatenator, $hostGroupId);
     }
@@ -177,7 +372,7 @@ class DbReadHostGroupRepository extends AbstractRepositoryDRB implements ReadHos
 
             return $this->exist($hostGroupIds);
         }
-        $concatenator = $this->getFindHostGroupConcatenator($accessGroupIds);
+        $concatenator = $this->getFindHostGroupConcatenator(null, $accessGroupIds);
 
         return $this->existHostGroups($concatenator, $hostGroupIds);
     }
@@ -224,7 +419,7 @@ class DbReadHostGroupRepository extends AbstractRepositoryDRB implements ReadHos
 
             return $this->findByHost($hostId);
         }
-        $concatenator = $this->getFindHostGroupConcatenator($accessGroupIds);
+        $concatenator = $this->getFindHostGroupConcatenator(null, $accessGroupIds);
 
         return $this->retrieveHostGroupsByHost($concatenator, $hostId);
     }
@@ -275,16 +470,19 @@ class DbReadHostGroupRepository extends AbstractRepositoryDRB implements ReadHos
     }
 
     /**
+     * @param ?RequestParametersInterface $requestParameters
      * @param list<int> $accessGroupIds
      *
      * @return SqlConcatenator
      */
-    private function getFindHostGroupConcatenator(array $accessGroupIds = []): SqlConcatenator
-    {
+    private function getFindHostGroupConcatenator(
+        ?RequestParametersInterface $requestParameters = null,
+        array $accessGroupIds = []
+    ): SqlConcatenator {
         $concatenator = (new SqlConcatenator())
             ->defineSelect(
                 <<<'SQL'
-                    SELECT
+                    SELECT DISTINCT
                         hg.hg_id,
                         hg.hg_name,
                         hg.hg_alias,
@@ -311,7 +509,24 @@ class DbReadHostGroupRepository extends AbstractRepositoryDRB implements ReadHos
                     SQL
             );
 
+        $hostCategoryAcls = '';
         if ([] !== $accessGroupIds) {
+            if ($this->hasRestrictedAccessToHostCategories($accessGroupIds)) {
+                $hostCategoryAcls = <<<'SQL'
+                    AND hcr.hostcategories_hc_id IN (
+                        SELECT arhcr.hc_id
+                        FROM `:db`.acl_resources_hc_relations arhcr
+                        INNER JOIN `:db`.acl_resources res
+                            ON res.acl_res_id = arhcr.acl_res_id
+                        INNER JOIN `:db`.acl_res_group_relations argr
+                            ON argr.acl_res_id = res.acl_res_id
+                        INNER JOIN `:db`.acl_groups ag
+                            ON ag.acl_group_id = argr.acl_group_id
+                        WHERE ag.acl_group_id IN (:ids)
+                    )
+                    SQL;
+            }
+
             $concatenator
                 ->appendJoins(
                     <<<'SQL'
@@ -333,6 +548,22 @@ class DbReadHostGroupRepository extends AbstractRepositoryDRB implements ReadHos
                 ->storeBindValueMultiple(':ids', $accessGroupIds, \PDO::PARAM_INT);
         }
 
+        $search = $requestParameters?->getSearchAsString();
+        if ($search !== null && \str_contains($search, 'hostcategory')) {
+            $concatenator->appendJoins(
+                <<<SQL
+                    LEFT JOIN `:db`.hostgroup_relation hgr
+                        ON hgr.hostgroup_hg_id = hg.hg_id
+                    LEFT JOIN `:db`.hostcategories_relation hcr
+                        ON hcr.host_host_id = hgr.host_host_id
+                        {$hostCategoryAcls}
+                    LEFT JOIN `:db`.hostcategories hc
+                        ON hc.hc_id = hcr.hostcategories_hc_id
+                        AND hc.level IS NULL
+                    SQL
+            );
+        }
+
         return $concatenator;
     }
 
@@ -344,60 +575,11 @@ class DbReadHostGroupRepository extends AbstractRepositoryDRB implements ReadHos
     private function accessGroupsToIds(array $accessGroups): array
     {
         return array_map(
-            static fn(AccessGroup $accessGroup) => $accessGroup->getId(),
+            static fn (AccessGroup $accessGroup) => $accessGroup->getId(),
             $accessGroups
         );
     }
 
-    /**
-     * @param SqlConcatenator $concatenator
-     * @param RequestParametersInterface|null $requestParameters
-     *
-     * @throws InvalidGeoCoordException
-     * @throws RequestParametersTranslatorException
-     * @throws \InvalidArgumentException
-     * @throws \PDOException
-     * @throws AssertionFailedException
-     *
-     * @return list<HostGroup>
-     */
-    private function retrieveHostGroups(
-        SqlConcatenator $concatenator,
-        ?RequestParametersInterface $requestParameters
-    ): array {
-        // If we use RequestParameters
-        $sqlTranslator = $requestParameters ? new SqlRequestParametersTranslator($requestParameters) : null;
-        $sqlTranslator?->setConcordanceArray([
-            'id' => 'hg.hg_id',
-            'alias' => 'hg.hg_alias',
-            'name' => 'hg.hg_name',
-            'is_activated' => 'hg.hg_activate',
-        ]);
-        $sqlTranslator?->addNormalizer('is_activated', new BoolToEnumNormalizer());
-
-        // Update the SQL string builder with the RequestParameters through SqlRequestParametersTranslator
-        $sqlTranslator?->translateForConcatenator($concatenator);
-
-        // Prepare SQL + bind values
-        $statement = $this->db->prepare($this->translateDbName($concatenator->concatAll()));
-        $sqlTranslator?->bindSearchValues($statement);
-        $concatenator->bindValuesToStatement($statement);
-        $statement->setFetchMode(\PDO::FETCH_ASSOC);
-        $statement->execute();
-
-        // Calculate the number of rows for the pagination.
-        $sqlTranslator?->calculateNumberOfRows($this->db);
-
-        // Retrieve data
-        $hostGroups = [];
-        foreach ($statement as $result) {
-            /** @var HostGroupResultSet $result */
-            $hostGroups[] = $this->createHostGroupFromArray($result);
-        }
-
-        return $hostGroups;
-    }
-
     /**
      * @param SqlConcatenator $concatenator
      * @param int $hostId
@@ -539,47 +721,6 @@ class DbReadHostGroupRepository extends AbstractRepositoryDRB implements ReadHos
         return $data ? $this->createHostGroupFromArray($data) : null;
     }
 
-    /**
-     * Determine if accessGroups give access to all hostGroups
-     * true: all host groups are accessible
-     * false: all host groups are NOT accessible.
-     *
-     * @param list<int> $accessGroupIds
-     *
-     * @return bool
-     */
-    private function hasAccessToAllHostGroups(array $accessGroupIds): bool
-    {
-        $concatenator = new SqlConcatenator();
-
-        $concatenator->defineSelect(
-            <<<'SQL'
-                SELECT res.all_hostgroups
-                FROM `:db`.acl_resources res
-                INNER JOIN `:db`.acl_res_group_relations argr
-                    ON res.acl_res_id = argr.acl_res_id
-                INNER JOIN `:db`.acl_groups ag
-                    ON argr.acl_group_id = ag.acl_group_id
-                SQL
-        );
-
-        $concatenator->storeBindValueMultiple(':access_group_ids', $accessGroupIds, \PDO::PARAM_INT)
-            ->appendWhere('ag.acl_group_id IN (:access_group_ids)');
-
-        $statement = $this->db->prepare($this->translateDbName($concatenator->__toString()));
-
-        $concatenator->bindValuesToStatement($statement);
-        $statement->execute();
-
-        while (false !== ($hasAccessToAll = $statement->fetchColumn())) {
-            if (true === (bool) $hasAccessToAll) {
-                return true;
-            }
-        }
-
-        return false;
-    }
-
     /**
      * @param array $result
      *
@@ -610,4 +751,43 @@ class DbReadHostGroupRepository extends AbstractRepositoryDRB implements ReadHos
             (bool) $result['hg_activate'],
         );
     }
+
+    /**
+     * Determines if host categories are filtered for given access group ids
+     * true: accessible host categories are filtered (only specified are accessible)
+     * false: accessible host categories are NOT filtered (all are accessible).
+     *
+     * @param int[] $accessGroupIds
+     *
+     * @phpstan-param non-empty-array<int> $accessGroupIds
+     *
+     * @return bool
+     */
+    private function hasRestrictedAccessToHostCategories(array $accessGroupIds): bool
+    {
+        $bindValuesArray = [];
+        foreach ($accessGroupIds as $index => $accessGroupId) {
+            $bindValuesArray[':acl_group_id_' . $index] = $accessGroupId;
+        }
+        $bindParamsAsString = \implode(',', \array_keys($bindValuesArray));
+        $statement = $this->db->prepare($this->translateDbName(
+            <<<SQL
+                SELECT 1
+                FROM `:db`.acl_resources_hc_relations arhcr
+                INNER JOIN `:db`.acl_resources res
+                    ON res.acl_res_id = arhcr.acl_res_id
+                INNER JOIN `:db`.acl_res_group_relations argr
+                    ON argr.acl_res_id = res.acl_res_id
+                INNER JOIN `:db`.acl_groups ag
+                    ON ag.acl_group_id = argr.acl_group_id
+                WHERE ag.acl_group_id IN ({$bindParamsAsString})
+                SQL
+        ));
+        foreach ($bindValuesArray as $bindParam => $bindValue) {
+            $statement->bindValue($bindParam, $bindValue, \PDO::PARAM_INT);
+        }
+        $statement->execute();
+
+        return (bool) $statement->fetchColumn();
+    }
 }
