@@ -23,6 +23,7 @@ declare(strict_types=1);
 
 namespace Core\MonitoringServer\Application\Repository;
 
+use Centreon\Domain\Exception\EntityNotFoundException;
 use Core\MonitoringServer\Model\MonitoringServer;
 use Core\Security\AccessGroup\Domain\Model\AccessGroup;
 
@@ -32,8 +33,6 @@ interface ReadMonitoringServerRepositoryInterface {
      *
      * @param int $monitoringServerId
      *
-     * @throws \Throwable
-     *
      * @return bool
      */
     public function exists(int $monitoringServerId): bool;
@@ -44,8 +43,6 @@ interface ReadMonitoringServerRepositoryInterface {
      * @param int $monitoringServerId
      * @param AccessGroup[] $accessGroups
      *
-     * @throws \Throwable
-     *
      * @return bool
      */
     public function existsByAccessGroups(int $monitoringServerId, array $accessGroups): bool;
@@ -55,8 +52,6 @@ interface ReadMonitoringServerRepositoryInterface {
      *
      * @param int $hostId
      *
-     * @throws \Throwable
-     *
      * @return MonitoringServer|null
      */
     public function findByHost(int $hostId): ?MonitoringServer;
@@ -66,9 +61,25 @@ interface ReadMonitoringServerRepositoryInterface {
      *
      * @param int[] $ids
      *
-     * @throws \Throwable
-     *
      * @return MonitoringServer[]
      */
     public function findByIds(array $ids): array;
+
+    /**
+     * Find all the Monitoring Servers.
+     *
+     * @return MonitoringServer[]
+     */
+    public function findAll(): array;
+
+    /**
+     * Get a monitoring server.
+     *
+     * @param int $monitoringServerId
+     *
+     * @throws EntityNotFoundException when no Monitoring server are found
+     *
+     * @return MonitoringServer
+     */
+    public function get(int $monitoringServerId): MonitoringServer;
 }
