@@ -167,7 +167,7 @@ class FindResourcesByParentPresenter extends AbstractPresenter implements FindRe
                 'downtime' => $endpoints['downtime'],
                 'check' => $endpoints['check'],
                 'forced_check' => $endpoints['forced_check'],
-                'metrics' => $endpoints['metrics'],
+                'metrics' => $endpoints['metrics'] ?? null,
             ],
             'uris' => $this->hypermediaCreator->createInternalUris($parameters),
             'externals' => [
