@@ -23,16 +23,18 @@ declare(strict_types=1);
 
 namespace Core\Security\ProviderConfiguration\Domain\OpenId\Model;
 
+use Core\Security\ProviderConfiguration\Domain\Exception\ConfigurationException;
 use Security\Domain\Authentication\Interfaces\ProviderConfigurationInterface;
 
-final class Configuration extends \Core\Security\ProviderConfiguration\Domain\Model\Configuration implements ProviderConfigurationInterface
+class Configuration extends \Core\Security\ProviderConfiguration\Domain\Model\Configuration implements ProviderConfigurationInterface
 {
     /**
      * @return CustomConfiguration
      */
     public function getCustomConfiguration(): CustomConfiguration
     {
-        /** @phpstan-ignore-next-line */
-        return $this->customConfiguration;
+        return $this->customConfiguration instanceof CustomConfiguration
+            ? $this->customConfiguration
+            : throw ConfigurationException::unexpectedCustomConfiguration(($this->customConfiguration)::class);
     }
 }
