@@ -62,7 +62,7 @@ class DbReadUserRepository extends AbstractRepositoryRDB implements ReadUserRepo
         $concatenator = new SqlConcatenator();
         $concatenator->defineSelect(
             <<<'SQL'
-                SELECT SQL_CALC_FOUND_ROWS
+                SELECT DISTINCT SQL_CALC_FOUND_ROWS
                     contact_id,
                     contact_alias,
                     contact_name,
@@ -88,6 +88,7 @@ class DbReadUserRepository extends AbstractRepositoryRDB implements ReadUserRepo
             'name' => 'contact_name',
             'email' => 'contact_email',
             'provider_name' => 'contact_auth_type',
+            'is_admin' => 'contact_admin',
         ]);
         $sqlTranslator->translateForConcatenator($concatenator);
 
@@ -129,7 +130,7 @@ class DbReadUserRepository extends AbstractRepositoryRDB implements ReadUserRepo
         $concatenator = new SqlConcatenator();
         $concatenator->defineSelect(
             <<<'SQL'
-                SELECT SQL_CALC_FOUND_ROWS
+                SELECT DISTINCT SQL_CALC_FOUND_ROWS
                     contact_id,
                     contact_alias,
                     contact_name,
@@ -165,6 +166,7 @@ class DbReadUserRepository extends AbstractRepositoryRDB implements ReadUserRepo
             'name' => 'contact_name',
             'email' => 'contact_email',
             'provider_name' => 'contact_auth_type',
+            'is_admin' => 'contact_admin',
         ]);
         $sqlTranslator->translateForConcatenator($concatenator);
 
