@@ -34,10 +34,13 @@ use Centreon\Domain\RequestParameters\{
     Interfaces\RequestParametersInterface, RequestParameters, RequestParametersException
 };
 use Centreon\Domain\VersionHelper;
+use Core\Common\Domain\Exception\RepositoryException;
+use Core\Common\Infrastructure\ExceptionLogger\ExceptionLogger;
 use JMS\Serializer\Exception\ValidationFailedException;
-use Psr\Log\LoggerInterface;
+use Psr\Log\LogLevel;
 use Symfony\Component\DependencyInjection\Exception\InvalidArgumentException;
 use Symfony\Component\EventDispatcher\EventSubscriberInterface;
+use Symfony\Component\HttpFoundation\Request;
 use Symfony\Component\HttpFoundation\Response;
 use Symfony\Component\HttpKernel\Event\{
     ExceptionEvent, RequestEvent, ResponseEvent
@@ -71,7 +74,7 @@ class CentreonEventSubscriber implements EventSubscriberInterface
      * @param Security $security
      * @param ApiPlatform $apiPlatform
      * @param ContactInterface $contact
-     * @param LoggerInterface $logger
+     * @param ExceptionLogger $exceptionLogger
      * @param string $apiVersionLatest
      * @param string $apiHeaderName
      * @param string $translationPath
@@ -81,12 +84,11 @@ class CentreonEventSubscriber implements EventSubscriberInterface
         readonly private Security $security,
         readonly private ApiPlatform $apiPlatform,
         readonly private ContactInterface $contact,
-        readonly private LoggerInterface $logger,
+        readonly private ExceptionLogger $exceptionLogger,
         readonly private string $apiVersionLatest,
         readonly private string $apiHeaderName,
         readonly private string $translationPath,
-    ) {
-    }
+    ) {}
 
     /**
      * Returns an array of event names this subscriber wants to listen to.
@@ -315,7 +317,6 @@ class CentreonEventSubscriber implements EventSubscriberInterface
                 $statusCode = $event->getThrowable()->getCode()
                     ?: Response::HTTP_INTERNAL_SERVER_ERROR;
             }
-            $this->logException($event->getThrowable());
             // Manage exception outside controllers
             $event->setResponse(
                 new Response(
@@ -348,7 +349,10 @@ class CentreonEventSubscriber implements EventSubscriberInterface
                         true
                     ),
                 ]);
-            } elseif ($event->getThrowable() instanceof \PDOException) {
+            } elseif (
+                $event->getThrowable() instanceof \PDOException
+                || $event->getThrowable() instanceof RepositoryException
+            ) {
                 $errorMessage = json_encode([
                     'code' => $errorCode,
                     'message' => 'An error has occurred in a repository',
@@ -370,29 +374,55 @@ class CentreonEventSubscriber implements EventSubscriberInterface
                     'message' => $event->getThrowable()->getMessage(),
                 ]);
             }
-            $this->logException($event->getThrowable());
             $event->setResponse(
                 new Response($errorMessage, $httpCode)
             );
         }
+        $this->logException($event->getThrowable());
     }
 
     /**
      * Set contact if he is logged in.
+     *
+     * @param RequestEvent $event
      */
-    public function initUser(): void
+    public function initUser(RequestEvent $event): void
     {
-        if ($user = $this->security->getUser()) {
-            /**
-             * @var Contact $user
-             */
-            EntityCreator::setContact($user);
-            /**
-             * @var ContactInterface $user
-             */
-            $this->initLanguage($user);
-            $this->initGlobalContact($user);
+        /** @var ?Contact $user */
+        $user = $this->security->getUser();
+        if ($user === null) {
+            return;
         }
+        
+        $request = $event->getRequest();
+        if ($user->getLang() === 'browser') {
+            $locale = $this->guessLocale($request);
+            $user->setLocale($locale);
+        }
+
+        EntityCreator::setContact($user);
+        
+        $this->initLanguage($user);
+        $this->initGlobalContact($user);
+    }
+
+    /**
+     * Guess the locale to use according to the provided Accept-Language header (sent by browser or http client).
+     * 
+     * @todo improve this by moving the logic in a dedicated service
+     * @todo improve the array of supported locales by INJECTING them instead
+     *
+     * @param Request $request
+     */
+    private function guessLocale(Request $request): string
+    {
+        $preferredLanguage = $request->getPreferredLanguage(['fr-FR', 'en-US', 'es-ES', 'pr-BR', 'pt-PT', 'de-DE']);
+        
+        // Reformating is necessary as the standard format uses "-" and we decided to store "_"
+        $locale = $preferredLanguage ? str_replace('-', '_', $preferredLanguage): 'en_US';
+
+        // Also Safari has its own format "fr-fr" instead of "fr-FR" hence the strtoupper
+        return substr($locale, 0, -2) . strtoupper(substr($locale, -2));
     }
 
     /**
@@ -403,10 +433,15 @@ class CentreonEventSubscriber implements EventSubscriberInterface
     private function logException(\Throwable $exception): void
     {
         if (! $exception instanceof HttpExceptionInterface || $exception->getCode() >= 500) {
-            $this->logger->critical($exception->getMessage(), ['context' => $exception]);
+            $level = LogLevel::CRITICAL;
         } else {
-            $this->logger->error($exception->getMessage(), ['context' => $exception]);
+            $level = LogLevel::ERROR;
         }
+        $this->exceptionLogger->log(
+            throwable: $exception,
+            context: ['internal_error' => $exception],
+            level: $level
+        );
     }
 
     /**
@@ -416,8 +451,7 @@ class CentreonEventSubscriber implements EventSubscriberInterface
      */
     private function initLanguage(ContactInterface $user): void
     {
-        $locale = $user->getLocale() ?? $this->getBrowserLocale();
-        $lang = $locale . '.' . Contact::DEFAULT_CHARSET;
+        $lang = $user->getLocale() . '.' . Contact::DEFAULT_CHARSET;
 
         putenv('LANG=' . $lang);
         setlocale(LC_ALL, $lang);
@@ -426,18 +460,6 @@ class CentreonEventSubscriber implements EventSubscriberInterface
         textdomain('messages');
     }
 
-    /**
-     * Get browser locale if set in http header.
-     *
-     * @return string The browser locale
-     */
-    private function getBrowserLocale(): string
-    {
-        return isset($_SERVER['HTTP_ACCEPT_LANGUAGE'])
-            ? (string) \Locale::acceptFromHttp($_SERVER['HTTP_ACCEPT_LANGUAGE'])
-            : Contact::DEFAULT_LOCALE;
-    }
-
     /**
      * Initialise the contact that will be used as the Service.
      * This will not change the user identified during authentication.
