@@ -9,12 +9,10 @@ import {
 import { configureProviderAcls } from '../../../../commons';
 
 before(() => {
-  cy.startWebContainer()
-    .startOpenIdProviderContainer()
-    .then(() => {
-      configureProviderAcls();
-      initializeSAMLUser();
-    });
+  cy.startContainers({ profiles: ['saml'] }).then(() => {
+    configureProviderAcls();
+    initializeSAMLUser();
+  });
 });
 
 beforeEach(() => {
@@ -38,6 +36,10 @@ beforeEach(() => {
     method: 'POST',
     url: '/centreon/api/latest/authentication/providers/configurations/local'
   }).as('postLocalAuthentification');
+  cy.intercept({
+    method: 'GET',
+    url: '/centreon/api/latest/users/filters/events-view?page=1&limit=100'
+  }).as('getFilters');
 });
 
 Given('an administrator is logged on the platform', () => {
@@ -128,7 +130,9 @@ Then(
 
     cy.visit('/').getByLabel({ label: 'Login with SAML', tag: 'a' }).click();
     cy.loginKeycloak(username);
+
     cy.url().should('include', '/monitoring/resources');
+    cy.wait('@getFilters').its('response.statusCode').should('eq', 200);
   }
 );
 
@@ -136,5 +140,5 @@ after(() => {
   // avoid random "Cannot read properties of null (reading 'postMessage')" when stopping containers
   cy.on('uncaught:exception', () => false);
 
-  cy.stopWebContainer().stopOpenIdProviderContainer();
+  cy.stopContainers();
 });
