@@ -2,9 +2,10 @@ import { Given, Then, When } from '@badeball/cypress-cucumber-preprocessor';
 import { last } from 'ramda';
 
 import dashboards from '../../../fixtures/dashboards/creation/dashboards.json';
+import textWidget from '../../../fixtures/dashboards/creation/widgets/textWidget.json';
 
 before(() => {
-  cy.startWebContainer();
+  cy.startContainers();
   cy.enableDashboardFeature();
   cy.executeCommandsViaClapi(
     'resources/clapi/config-ACL/dashboard-configuration-creator.json'
@@ -12,7 +13,7 @@ before(() => {
 });
 
 after(() => {
-  cy.stopWebContainer();
+  cy.stopContainers();
 });
 
 beforeEach(() => {
@@ -44,7 +45,7 @@ afterEach(() => {
 Given(
   'a user with dashboard edition rights on the dashboard listing page',
   () => {
-    cy.visit(`${Cypress.config().baseUrl}/centreon/home/dashboards`);
+    cy.visit('/centreon/home/dashboards');
   }
 );
 
@@ -120,7 +121,7 @@ Then('the newly created dashboard has the required only dashboard data', () => {
 Given(
   'a user with dashboard edition rights on the dashboard creation form',
   () => {
-    cy.visit(`${Cypress.config().baseUrl}/centreon/home/dashboards`);
+    cy.visit('/centreon/home/dashboards');
     cy.getByLabel({ label: 'create', tag: 'button' }).click();
   }
 );
@@ -156,7 +157,7 @@ Then(
 Given(
   'a user with dashboard edition rights who is about to create a dashboard',
   () => {
-    cy.visit(`${Cypress.config().baseUrl}/centreon/home/dashboards`);
+    cy.visit('/centreon/home/dashboards');
     cy.getByLabel({ label: 'create', tag: 'button' }).click();
     cy.getByLabel({ label: 'Name', tag: 'input' }).type(
       `${dashboards.default.name} to be cancelled`
@@ -192,3 +193,43 @@ Then('the form fields are empty', () => {
   cy.getByLabel({ label: 'Name', tag: 'input' }).should('be.empty');
   cy.getByLabel({ label: 'Description', tag: 'textarea' }).should('be.empty');
 });
+
+Given(
+  "a dashboard with existing widgets in the dashboard administrator user's dashboard library",
+  () => {
+    cy.insertDashboardWithWidget(
+      dashboards.fromDashboardCreatorUser,
+      textWidget
+    );
+    cy.visit('/centreon/home/dashboards');
+  }
+);
+
+When('the dashboard administrator user starts to edit the dashboard', () => {
+  cy.contains(dashboards.fromDashboardCreatorUser.name).click();
+  cy.getByTestId({ testId: 'edit_dashboard' }).click();
+  cy.location('search').should('include', 'edit=true');
+  cy.get('button[type=button]').contains('Add a widget').should('exist');
+});
+
+Then("creates a new dashboard on the previous dashboard's edition page", () => {
+  cy.getByTestId({ testId: 'ArrowDropDownIcon' }).click();
+  cy.contains('Create a dashboard').click();
+  cy.getByLabel({ label: 'Name', tag: 'input' }).type(dashboards.default.name);
+  cy.getByLabel({ label: 'Description', tag: 'textarea' }).type(
+    dashboards.default.description
+  );
+  cy.getByLabel({ label: 'Create', tag: 'button' }).click();
+  cy.wait('@createDashboard');
+});
+
+Then(
+  "the user is redirected to the newly created dashboard's edition page",
+  () => {
+    cy.url().should('match', /\/dashboards\/library\/\d+\?edit=true/);
+  }
+);
+
+Then('the newly created dashboard is empty', () => {
+  cy.get('[class*="addWidgetPanel"]').should('be.visible');
+});
