@@ -8,7 +8,7 @@ import dashboardCreatorUser from '../../../fixtures/users/user-dashboard-creator
 import dashboardViewerUser from '../../../fixtures/users/user-dashboard-viewer.json';
 
 before(() => {
-  cy.startWebContainer();
+  cy.startContainers();
   cy.enableDashboardFeature();
   cy.executeCommandsViaClapi(
     'resources/clapi/config-ACL/dashboard-check-permissions.json'
@@ -65,11 +65,11 @@ after(() => {
     database: 'centreon',
     query: 'DELETE FROM dashboard'
   });
-  cy.stopWebContainer();
+  cy.stopContainers();
 });
 
 afterEach(() => {
-  cy.visit(`${Cypress.config().baseUrl}/centreon/home/dashboards`);
+  cy.visit('/centreon/home/dashboards/library');
   cy.logout();
 });
 
@@ -81,42 +81,26 @@ Given('an admin user is logged in on a platform with dashboards', () => {
 });
 
 When('the admin user accesses the dashboards library', () => {
-  cy.visit(`${Cypress.config().baseUrl}/centreon/home/dashboards`);
+  cy.navigateTo({
+    page: 'Dashboards',
+    rootItemNumber: 0
+  });
+  cy.wait('@listAllDashboards');
 });
 
 Then(
   'the admin user can view all the dashboards configured on the platform',
   () => {
-    cy.getByLabel({
-      label: 'view',
-      tag: 'button'
-    })
-      .contains(dashboards.fromAdminUser.name)
-      .should('exist');
+    cy.contains(dashboards.fromAdminUser.name).should('exist');
 
-    cy.getByLabel({
-      label: 'view',
-      tag: 'button'
-    })
-      .contains(dashboards.fromDashboardAdministratorUser.name)
-      .should('exist');
+    cy.contains(dashboards.fromDashboardAdministratorUser.name).should('exist');
 
-    cy.getByLabel({
-      label: 'view',
-      tag: 'button'
-    })
-      .contains(dashboards.fromDashboardCreatorUser.name)
-      .should('exist');
+    cy.contains(dashboards.fromDashboardCreatorUser.name).should('exist');
   }
 );
 
 When('the admin user clicks on a dashboard', () => {
-  cy.getByLabel({
-    label: 'view',
-    tag: 'button'
-  })
-    .contains(dashboards.fromAdminUser.name)
-    .click();
+  cy.contains(dashboards.fromAdminUser.name).click();
 });
 
 Then(
@@ -155,7 +139,8 @@ Then(
 
 Then("the admin user is allowed to update the dashboard's properties", () => {
   cy.getByLabel({ label: 'edit', tag: 'button' }).click();
-
+  cy.get('body').type('{esc}');
+  cy.getByLabel({ label: 'edit', tag: 'button' }).click();
   cy.getByLabel({ label: 'Name', tag: 'input' }).type(
     `{selectall}{backspace}${dashboards.fromAdminUser.name}-edited`
   );
@@ -187,7 +172,11 @@ Given('an admin user on the dashboards library', () => {
 });
 
 When('the admin user creates a new dashboard', () => {
-  cy.visit(`${Cypress.config().baseUrl}/centreon/home/dashboards`);
+  cy.navigateTo({
+    page: 'Dashboards',
+    rootItemNumber: 0
+  });
+  cy.wait('@listAllDashboards');
   cy.getByTestId({ testId: 'create-dashboard' }).eq(0).click();
   cy.getByLabel({ label: 'Name', tag: 'input' }).type(
     dashboards.fromCurrentUser.name
@@ -227,35 +216,32 @@ Given('an admin user who has just created a dashboard', () => {
     loginViaApi: false
   });
 
-  cy.visit(`${Cypress.config().baseUrl}/centreon/home/dashboards`);
+  cy.navigateTo({
+    page: 'Dashboards',
+    rootItemNumber: 0
+  });
+  cy.wait('@listAllDashboards');
 
-  cy.getByLabel({
-    label: 'view',
-    tag: 'button'
-  })
-    .contains(dashboards.fromCurrentUser.name)
-    .should('exist');
+  cy.contains(dashboards.fromCurrentUser.name).should('exist');
 });
 
 When('the admin user deletes the newly created dashboard', () => {
   cy.contains(dashboards.fromCurrentUser.name)
     .parent()
-    .find('button[aria-label="delete"]')
+    .parent()
+    .find('button[aria-label="More actions"]')
     .click();
 
   cy.getByLabel({ label: 'Delete', tag: 'li' }).click();
+
+  cy.getByLabel({ label: 'Delete', tag: 'button' }).click();
   cy.wait('@listAllDashboards');
 });
 
 Then(
   "the admin's dashboard is deleted and does not appear anymore in the dashboards library",
   () => {
-    cy.getByLabel({
-      label: 'view',
-      tag: 'button'
-    })
-      .contains(dashboards.fromCurrentUser.name)
-      .should('not.exist');
+    cy.contains(dashboards.fromCurrentUser.name).should('not.exist');
   }
 );
 
@@ -270,42 +256,26 @@ Given(
 );
 
 When('the dashboard administrator user accesses the dashboards library', () => {
-  cy.visit(`${Cypress.config().baseUrl}/centreon/home/dashboards`);
+  cy.navigateTo({
+    page: 'Dashboards',
+    rootItemNumber: 0
+  });
+  cy.wait('@listAllDashboards');
 });
 
 Then(
   'the dashboard administrator user can consult all the dashboards configured on the platform',
   () => {
-    cy.getByLabel({
-      label: 'view',
-      tag: 'button'
-    })
-      .contains(dashboards.fromAdminUser.name)
-      .should('exist');
+    cy.contains(dashboards.fromAdminUser.name).should('exist');
 
-    cy.getByLabel({
-      label: 'view',
-      tag: 'button'
-    })
-      .contains(dashboards.fromDashboardAdministratorUser.name)
-      .should('exist');
+    cy.contains(dashboards.fromDashboardAdministratorUser.name).should('exist');
 
-    cy.getByLabel({
-      label: 'view',
-      tag: 'button'
-    })
-      .contains(dashboards.fromDashboardCreatorUser.name)
-      .should('exist');
+    cy.contains(dashboards.fromDashboardCreatorUser.name).should('exist');
   }
 );
 
 When('the dashboard administrator user clicks on a dashboard', () => {
-  cy.getByLabel({
-    label: 'view',
-    tag: 'button'
-  })
-    .contains(dashboards.fromDashboardAdministratorUser.name)
-    .click();
+  cy.contains(dashboards.fromDashboardAdministratorUser.name).click();
 });
 
 Then(
@@ -384,7 +354,11 @@ Given(
 );
 
 When('the dashboard administrator user creates a new dashboard', () => {
-  cy.visit(`${Cypress.config().baseUrl}/centreon/home/dashboards`);
+  cy.navigateTo({
+    page: 'Dashboards',
+    rootItemNumber: 0
+  });
+  cy.wait('@listAllDashboards');
   cy.getByTestId({ testId: 'create-dashboard' }).eq(0).click();
   cy.getByLabel({ label: 'Name', tag: 'input' }).type(
     dashboards.fromCurrentUser.name
@@ -423,14 +397,13 @@ Given('a dashboard administrator user who has just created a dashboard', () => {
     loginViaApi: false
   });
 
-  cy.visit(`${Cypress.config().baseUrl}/centreon/home/dashboards`);
+  cy.navigateTo({
+    page: 'Dashboards',
+    rootItemNumber: 0
+  });
+  cy.wait('@listAllDashboards');
 
-  cy.getByLabel({
-    label: 'view',
-    tag: 'button'
-  })
-    .contains(dashboards.fromCurrentUser.name)
-    .should('exist');
+  cy.contains(dashboards.fromCurrentUser.name).should('exist');
 });
 
 When(
@@ -438,10 +411,13 @@ When(
   () => {
     cy.contains(dashboards.fromCurrentUser.name)
       .parent()
-      .find('button[aria-label="delete"]')
+      .parent()
+      .find('button[aria-label="More actions"]')
       .click();
 
     cy.getByLabel({ label: 'Delete', tag: 'li' }).click();
+
+    cy.getByLabel({ label: 'Delete', tag: 'button' }).click();
     cy.wait('@listAllDashboards');
   }
 );
@@ -449,12 +425,7 @@ When(
 Then(
   "the dashboard administrator's dashboard is deleted and does not appear anymore in the dashboards library",
   () => {
-    cy.getByLabel({
-      label: 'view',
-      tag: 'button'
-    })
-      .contains(dashboards.fromCurrentUser.name)
-      .should('not.exist');
+    cy.contains(dashboards.fromCurrentUser.name).should('not.exist');
   }
 );
 
@@ -469,42 +440,28 @@ Given(
 );
 
 When('the dashboard editor user accesses the dashboards library', () => {
-  cy.visit(`${Cypress.config().baseUrl}/centreon/home/dashboards`);
+  cy.navigateTo({
+    page: 'Dashboards',
+    rootItemNumber: 0
+  });
+  cy.wait('@listAllDashboards');
 });
 
 Then(
   'a list of the dashboards the dashboard editor user has access to is displayed',
   () => {
-    cy.getByLabel({
-      label: 'view',
-      tag: 'button'
-    })
-      .contains(dashboards.fromAdminUser.name)
-      .should('not.exist');
+    cy.contains(dashboards.fromAdminUser.name).should('not.exist');
 
-    cy.getByLabel({
-      label: 'view',
-      tag: 'button'
-    })
-      .contains(dashboards.fromDashboardAdministratorUser.name)
-      .should('not.exist');
+    cy.contains(dashboards.fromDashboardAdministratorUser.name).should(
+      'not.exist'
+    );
 
-    cy.getByLabel({
-      label: 'view',
-      tag: 'button'
-    })
-      .contains(dashboards.fromDashboardCreatorUser.name)
-      .should('exist');
+    cy.contains(dashboards.fromDashboardCreatorUser.name).should('exist');
   }
 );
 
 When('the dashboard editor user clicks on a dashboard', () => {
-  cy.getByLabel({
-    label: 'view',
-    tag: 'button'
-  })
-    .contains(dashboards.fromDashboardCreatorUser.name)
-    .click();
+  cy.contains(dashboards.fromDashboardCreatorUser.name).click();
 });
 
 Then(
@@ -581,7 +538,11 @@ Given('a non-admin user with the editor role on the dashboard feature', () => {
 });
 
 When('the dashboard editor user creates a new dashboard', () => {
-  cy.visit(`${Cypress.config().baseUrl}/centreon/home/dashboards`);
+  cy.navigateTo({
+    page: 'Dashboards',
+    rootItemNumber: 0
+  });
+  cy.wait('@listAllDashboards');
   cy.getByTestId({ testId: 'create-dashboard' }).eq(0).click();
   cy.getByLabel({ label: 'Name', tag: 'input' }).type(
     dashboards.fromCurrentUser.name
@@ -621,170 +582,154 @@ Given('a dashboard editor user who has just created a dashboard', () => {
     loginViaApi: false
   });
 
-  cy.visit(`${Cypress.config().baseUrl}/centreon/home/dashboards`);
+  cy.navigateTo({
+    page: 'Dashboards',
+    rootItemNumber: 0
+  });
+  cy.wait('@listAllDashboards');
 
-  cy.getByLabel({
-    label: 'view',
-    tag: 'button'
-  })
-    .contains(dashboards.fromCurrentUser.name)
-    .should('exist');
+  cy.contains(dashboards.fromCurrentUser.name).should('exist');
 });
 
 When('the dashboard editor user deletes the newly created dashboard', () => {
   cy.contains(dashboards.fromCurrentUser.name)
     .parent()
-    .find('button[aria-label="delete"]')
+    .parent()
+    .find('button[aria-label="More actions"]')
     .click();
 
   cy.getByLabel({ label: 'Delete', tag: 'li' }).click();
+
+  cy.getByLabel({ label: 'Delete', tag: 'button' }).click();
   cy.wait('@listAllDashboards');
 });
 
 Then(
   "the dashboard editor's dashboard is deleted and does not appear anymore in the dashboards library",
   () => {
-    cy.getByLabel({
-      label: 'view',
-      tag: 'button'
-    })
-      .contains(dashboards.fromCurrentUser.name)
-      .should('not.exist');
+    cy.contains(dashboards.fromCurrentUser.name).should('not.exist');
   }
 );
 
-// Given(
-//   'a non-admin user with the dashboard viewer role is logged in on a platform with dashboards',
-//   () => {
-//     cy.loginByTypeOfUser({
-//       jsonName: dashboardAdministratorUser.login,
-//       loginViaApi: true
-//     });
-//     cy.visit('/centreon/home/dashboards');
-//     cy.getByLabel({
-//       label: 'view',
-//       tag: 'button'
-//     })
-//       .contains(dashboards.fromDashboardCreatorUser.name)
-//       .click();
-//     cy.getByLabel({ label: 'share', tag: 'button' }).click();
-//     cy.getByLabel({ label: 'Open', tag: 'button' }).click();
-//     cy.contains(dashboardViewerUser.login).click();
-//     cy.getByTestId({ testId: 'add' }).click();
-//     cy.getByLabel({ label: 'Save', tag: 'button' })
-//       .should('be.enabled')
-//       .click();
-//     cy.logoutViaAPI();
-//     cy.loginByTypeOfUser({
-//       jsonName: dashboardViewerUser.login,
-//       loginViaApi: false
-//     });
-//   }
-// );
+Given(
+  'a non-admin user with the dashboard viewer role is logged in on a platform',
+  () => {
+    cy.loginByTypeOfUser({
+      jsonName: dashboardAdministratorUser.login,
+      loginViaApi: true
+    });
+    cy.navigateTo({
+      page: 'Dashboards',
+      rootItemNumber: 0
+    });
+    cy.contains(dashboards.fromDashboardCreatorUser.name).click();
+    cy.getByLabel({ label: 'share', tag: 'button' }).click();
+    cy.getByLabel({ label: 'Open', tag: 'button' }).click();
+    cy.contains(dashboardViewerUser.login).click();
+    cy.getByTestId({ testId: 'add' }).click();
+    cy.getByLabel({ label: 'Save', tag: 'button' })
+      .should('be.enabled')
+      .click();
+    cy.logoutViaAPI();
+    cy.loginByTypeOfUser({
+      jsonName: dashboardViewerUser.login,
+      loginViaApi: false
+    });
+  }
+);
 
-// When('the dashboard viewer user accesses the dashboards library', () => {
-//   cy.visit(`${Cypress.config().baseUrl}/centreon/home/dashboards`);
-// });
+When('the dashboard viewer user accesses the dashboards library', () => {
+  cy.navigateTo({
+    page: 'Dashboards',
+    rootItemNumber: 0
+  });
+  cy.wait('@listAllDashboards');
+});
 
-// Then(
-//   'a list of the dashboards the dashboard viewer user has access to is displayed',
-//   () => {
-//     cy.getByLabel({
-//       label: 'view',
-//       tag: 'button'
-//     })
-//       .contains(dashboards.fromAdminUser.name)
-//       .should('not.exist');
+Then(
+  'a list of the dashboards the dashboard viewer user has access to is displayed',
+  () => {
+    cy.contains(dashboards.fromAdminUser.name).should('not.exist');
 
-//     cy.getByLabel({
-//       label: 'view',
-//       tag: 'button'
-//     })
-//       .contains(dashboards.fromDashboardAdministratorUser.name)
-//       .should('not.exist');
+    cy.contains(dashboards.fromDashboardAdministratorUser.name).should(
+      'not.exist'
+    );
 
-//     cy.getByLabel({
-//       label: 'view',
-//       tag: 'button'
-//     })
-//       .contains(dashboards.fromDashboardCreatorUser.name)
-//       .should('exist');
-//   }
-// );
+    cy.contains(dashboards.fromDashboardCreatorUser.name).should('exist');
+  }
+);
 
-// When('the dashboard viewer user clicks on a dashboard', () => {
-//   cy.getByLabel({
-//     label: 'view',
-//     tag: 'button'
-//   })
-//     .contains(dashboards.fromDashboardCreatorUser.name)
-//     .click();
-// });
+When('the dashboard viewer user clicks on a dashboard', () => {
+  cy.contains(dashboards.fromDashboardCreatorUser.name).click();
+});
 
-// Then(
-//   'the dashboard viewer user is redirected to the detail page for this dashboard',
-//   () => {
-//     cy.location('pathname')
-//       .should('include', '/dashboards/')
-//       .invoke('split', '/')
-//       .should('not.be.empty')
-//       .then(last)
-//       .then(Number)
-//       .should('not.be', 'dashboards')
-//       .should('be.a', 'number');
+Then(
+  'the dashboard viewer user is redirected to the detail page for this dashboard',
+  () => {
+    cy.location('pathname')
+      .should('include', '/dashboards/')
+      .invoke('split', '/')
+      .should('not.be.empty')
+      .then(last)
+      .then(Number)
+      .should('not.be', 'dashboards')
+      .should('be.a', 'number');
 
-//     cy.getByLabel({ label: 'page header title' }).should(
-//       'contain.text',
-//       dashboards.fromDashboardCreatorUser.name
-//     );
-//     cy.getByLabel({ label: 'page header description' }).should(
-//       'contain.text',
-//       dashboards.fromDashboardCreatorUser.description
-//     );
-//   }
-// );
+    cy.getByLabel({ label: 'page header title' }).should(
+      'contain.text',
+      dashboards.fromDashboardCreatorUser.name
+    );
+    cy.getByLabel({ label: 'page header description' }).should(
+      'contain.text',
+      dashboards.fromDashboardCreatorUser.description
+    );
+  }
+);
 
-// Then(
-//   'the dashboard viewer user does not have access to any update or share-related options on a dashboard',
-//   () => {
-//     cy.getByTestId({ testId: 'edit' }).should('not.exist');
-//     cy.getByTestId({ testId: 'share' }).should('not.exist');
-//   }
-// );
+Then(
+  'the dashboard viewer user does not have access to any update or share-related options on a dashboard',
+  () => {
+    cy.getByTestId({ testId: 'edit' }).should('not.exist');
+    cy.getByTestId({ testId: 'share' }).should('not.exist');
+  }
+);
 
-// Given('a non-admin user with the viewer role on the dashboard feature', () => {
-//   cy.loginByTypeOfUser({
-//     jsonName: dashboardViewerUser.login,
-//     loginViaApi: false
-//   });
-// });
+Given('a non-admin user with the viewer role on the dashboard feature', () => {
+  cy.loginByTypeOfUser({
+    jsonName: dashboardViewerUser.login,
+    loginViaApi: false
+  });
+});
 
-// When('the dashboard viewer accesses the dashboards library', () => {
-//   cy.visit(`${Cypress.config().baseUrl}/centreon/home/dashboards`);
-// });
+When('the dashboard viewer accesses the dashboards library', () => {
+  cy.navigateTo({
+    page: 'Dashboards',
+    rootItemNumber: 0
+  });
+  cy.wait('@listAllDashboards');
+});
 
-// Then('the option to create a new dashboard is not displayed', () => {
-//   cy.getByTestId({ testId: 'create-dashboard' }).eq(0).should('not.exist');
-// });
+Then('the option to create a new dashboard is not displayed', () => {
+  cy.getByTestId({ testId: 'create-dashboard' }).should('not.exist');
+});
 
-// Given('a dashboard viewer user who could not create a dashboard', () => {
-//   cy.loginByTypeOfUser({
-//     jsonName: dashboardViewerUser.login,
-//     loginViaApi: false
-//   });
+Given('a dashboard viewer user who could not create a dashboard', () => {
+  cy.loginByTypeOfUser({
+    jsonName: dashboardViewerUser.login,
+    loginViaApi: false
+  });
 
-//   cy.visit(`${Cypress.config().baseUrl}/centreon/home/dashboards`);
-// });
+  cy.navigateTo({
+    page: 'Dashboards',
+    rootItemNumber: 0
+  });
+  cy.wait('@listAllDashboards');
+});
 
-// When('the dashboard viewer user tries to delete a dashboard', () => {
-//   cy.getByLabel({
-//     label: 'view',
-//     tag: 'button'
-//   })
-//     .contains(dashboards.fromDashboardCreatorUser.name)
-//     .should('exist');
-// });
+When('the dashboard viewer user tries to delete a dashboard', () => {
+  cy.contains(dashboards.fromDashboardCreatorUser.name).should('exist');
+});
 
-// Then('the button to delete a dashboard does not appear', () => {
-//   cy.getByTestId({ testId: 'delete' }).should('not.exist');
-// });
+Then('the button to delete a dashboard does not appear', () => {
+  cy.getByTestId({ testId: 'delete' }).should('not.exist');
+});
