@@ -1,3 +1,4 @@
+/* eslint-disable no-lonely-if */
 import { Given, Then, When } from '@badeball/cypress-cucumber-preprocessor';
 
 import { CopyToContainerContentType } from '@centreon/js-config/cypress/e2e/commands';
@@ -6,6 +7,9 @@ import { checkIfConfigurationIsExported, insertFixture } from '../../commons';
 
 const dateBeforeLogin = new Date();
 
+const localPackageDirectory = 'fixtures/packages';
+const containerPackageDirectory = '/tmp/packages-update-centreon';
+
 const getCentreonPreviousMajorVersion = (majorVersionFrom: string): string => {
   const match = majorVersionFrom.match(/^(\d+)\.(\d+)$/);
 
@@ -16,7 +20,7 @@ const getCentreonPreviousMajorVersion = (majorVersionFrom: string): string => {
   let year = match[1];
   let month = match[2];
 
-  if (month === '04') {
+  if (Number(month) <= 4 || Number(month) > 10) {
     year = (Number(year) - 1).toString();
     month = '10';
   } else {
@@ -35,7 +39,7 @@ const getCentreonStableMinorVersions = (
   if (Cypress.env('WEB_IMAGE_OS').includes('alma')) {
     commandResult = cy
       .execInContainer({
-        command: `dnf config-manager --set-disabled 'centreon-*-unstable*' 'centreon-*-testing*' 'mariadb*'`,
+        command: `dnf config-manager --set-disabled 'centreon-*-unstable*' 'centreon-*-testing*'`,
         name: 'web'
       })
       .execInContainer({
@@ -93,9 +97,60 @@ const getCentreonStableMinorVersions = (
   });
 };
 
+const installDatabase = (): void => {
+  if (Cypress.env('WEB_IMAGE_OS').includes('alma')) {
+    const osMatches = Cypress.env('WEB_IMAGE_OS').match(/alma(\d+)/);
+    cy.execInContainer({
+      command: [
+        `bash -e <<EOF
+          curl -LsS https://r.mariadb.com/downloads/mariadb_repo_setup | bash -s -- --os-type=rhel --skip-check-installed --skip-maxscale --os-version=${osMatches[1]} --mariadb-server-version="mariadb-10.5"
+EOF`,
+        `dnf install -y mariadb-server mariadb`,
+      ],
+      name: 'web'
+    });
+  } else {
+    let osType = 'debian';
+    let osVersion = '12';
+    if (Cypress.env('WEB_IMAGE_OS') === 'jammy') {
+      osType = 'ubuntu';
+      osVersion = 'jammy';
+    }
+    cy.execInContainer({
+      command: [
+        `bash -e <<EOF
+          curl -LsS https://r.mariadb.com/downloads/mariadb_repo_setup | bash -s -- --os-type=${osType} --skip-check-installed --skip-maxscale --os-version=${osVersion} --mariadb-server-version="mariadb-10.11"
+EOF`,
+        `apt-get update`,
+        `apt-get install -y mariadb-server mariadb-client`,
+      ],
+      name: 'web'
+    });
+  }
+
+};
+
 const installCentreon = (version: string): Cypress.Chainable => {
   cy.log(`installing version ${version}...`);
 
+  const versionMatches = version.match(/(\d+)\.(\d+)\.(\d+)/);
+  if (!versionMatches) {
+    throw new Error('Cannot parse version number.');
+  }
+
+  cy.execInContainer({
+    command: [
+      `mkdir -p /usr/lib/centreon/plugins`,
+      `chmod 0755 /usr/lib/centreon/plugins`,
+    ],
+    name: 'web'
+  });
+
+  if (Number(versionMatches[1]) > 24 || (Number(versionMatches[1]) === 24 && Number(versionMatches[2]) >= 10)) {
+    // database is not installed in dependencies containers > 24.10
+    installDatabase();
+  }
+
   if (Cypress.env('WEB_IMAGE_OS').includes('alma')) {
     cy.execInContainer({
       command: [
@@ -111,31 +166,73 @@ const installCentreon = (version: string): Cypress.Chainable => {
         `dnf config-manager --set-enabled 'centreon-*'`
       ],
       name: 'web'
-    });
+  });
   } else {
+    let packageDistribPrefix;
+    let packageDistribName;
+
+    if (Number(versionMatches[1]) < 24) {
+      packageDistribPrefix = '-';
+      packageDistribName = Cypress.env('WEB_IMAGE_OS');
+    } else if (
+      Number(versionMatches[1]) === 24 &&
+      Number(versionMatches[2]) < 10 &&
+      Number(versionMatches[3]) >= 10
+    ) {
+      packageDistribPrefix = '-1+';
+      packageDistribName = 'deb12u1';
+    } else if (Number(versionMatches[1]) === 24 && Number(versionMatches[2]) < 10) {
+      packageDistribPrefix = '-1~';
+      packageDistribName = 'bookworm';
+    } else if (Cypress.env('WEB_IMAGE_OS') === 'bookworm') {
+      packageDistribPrefix = '-1+';
+      packageDistribName = 'deb12u1';
+    } else if (Cypress.env('WEB_IMAGE_OS') === 'jammy') {
+      packageDistribPrefix = '-1+';
+      packageDistribName = '0ubuntu.22.04';
+    } else {
+      throw new Error(`Distrib ${Cypress.env('WEB_IMAGE_OS')} not managed in update/upgrade tests.`);
+    }
+
+    const packageVersionSuffix = `${version}${packageDistribPrefix}${packageDistribName}`;
+    cy.log(`packageVersionSuffix: ${packageVersionSuffix}`);
+
+    const packagesToInstall = [
+      `centreon-common='${packageVersionSuffix}'`,
+      `centreon-poller='${packageVersionSuffix}'`,
+      `centreon-web='${packageVersionSuffix}'`,
+      `centreon-perl-libs='${packageVersionSuffix}'`,
+      `centreon-trap='${packageVersionSuffix}'`,
+    ];
+
+    if (Number(versionMatches[1]) < 24) {
+      packagesToInstall.push(`centreon-web-apache=${packageVersionSuffix}`);
+    }
+    const phpVersion = Number(versionMatches[1]) <= 24 && Number(versionMatches[2]) < 10 ? '8.1' : '8.2';
+
     cy.execInContainer({
       command: [
         `mv /etc/apt/sources.list.d/centreon-unstable.list /etc/apt/sources.list.d/centreon-unstable.list.bak`,
         `mv /etc/apt/sources.list.d/centreon-testing.list /etc/apt/sources.list.d/centreon-testing.list.bak`,
         `apt-get update`,
-        `apt-get install -y centreon-poller=${version}-${Cypress.env('WEB_IMAGE_OS')} centreon-web-apache=${version}-${Cypress.env('WEB_IMAGE_OS')} centreon-web=${version}-${Cypress.env('WEB_IMAGE_OS')} centreon-common=${version}-${Cypress.env('WEB_IMAGE_OS')}`,
+        `apt-get install -y ${packagesToInstall.join(' ')}`,
         `mkdir -p /usr/lib/centreon-connector`,
-        `echo "date.timezone = Europe/Paris" >> /etc/php/8.1/mods-available/centreon.ini`,
+        `echo "date.timezone = Europe/Paris" > /etc/php/${phpVersion}/mods-available/timezone.ini`,
+        `phpenmod -v ${phpVersion} timezone`,
         `sed -i 's#^datadir_set=#datadir_set=1#' /etc/init.d/mysql`,
         `service mysql start`,
         `mkdir -p /run/php`,
-        `systemctl start php8.1-fpm`,
-        `systemctl start apache2`,
+        `systemctl restart php${phpVersion}-fpm`,
+        `systemctl restart apache2`,
         `mysql -e "GRANT ALL ON *.* to 'root'@'localhost' IDENTIFIED BY 'centreon' WITH GRANT OPTION"`,
         `mv /etc/apt/sources.list.d/centreon-unstable.list.bak /etc/apt/sources.list.d/centreon-unstable.list`,
         `mv /etc/apt/sources.list.d/centreon-testing.list.bak /etc/apt/sources.list.d/centreon-testing.list`,
         `apt-get update`,
-        `usermod -a -G centreon-broker www-data` // temporary fix (MON-20769)
+        `usermod -a -G centreon-broker www-data`
       ],
       name: 'web'
     });
   }
-
   cy.log(`Version ${version} installed on filesystem`);
 
   cy.intercept({
@@ -192,7 +289,7 @@ const installCentreon = (version: string): Cypress.Chainable => {
 
   // Step 7
   cy.get('th.step-wrapper span').contains(7);
-  cy.wait('@cacheGeneration', { timeout: 30000 })
+  cy.wait('@cacheGeneration', { timeout: 60000 })
     .get('tbody#step_contents span:contains("OK")')
     .should('have.length', 7);
   cy.wait('@nextStep').get('#next').click();
@@ -225,28 +322,70 @@ const installCentreon = (version: string): Cypress.Chainable => {
 const updatePlatformPackages = (): Cypress.Chainable => {
   return cy
     .copyToContainer({
-      destination: '/tmp/packages-update-centreon',
-      source: './fixtures/packages',
+      destination: containerPackageDirectory,
+      source: `./${localPackageDirectory}`,
       type: CopyToContainerContentType.Directory
     })
     .getWebVersion()
     .then(({ major_version }) => {
+      let installCommands: Array<string> = [];
+
       if (Cypress.env('WEB_IMAGE_OS').includes('alma')) {
-        return cy.execInContainer({
-          command: [
-            `rm -f /tmp/packages-update-centreon/centreon{,-central,-mariadb,-mysql}-${major_version}*.rpm`,
-            'dnf install -y /tmp/packages-update-centreon/*.rpm'
-          ],
-          name: 'web'
-        });
+        if ([Cypress.env('STABILITY'), Cypress.env('TARGET_STABILITY')].includes('testing')) {
+          installCommands = [
+            ...installCommands,
+            `dnf config-manager --set-disabled 'centreon*unstable*'`
+          ];
+        } else if (Cypress.env('STABILITY') === 'stable') {
+          installCommands = [
+            ...installCommands,
+            `dnf config-manager --set-disabled 'centreon*unstable*' --set-disabled 'centreon*testing*'`
+          ];
+        }
+      } else {
+        if ([Cypress.env('STABILITY'), Cypress.env('TARGET_STABILITY')].includes('testing')) {
+          installCommands = [
+            ...installCommands,
+            `rm -f /etc/apt/sources.list.d/centreon*unstable*`
+          ];
+        } else if (Cypress.env('STABILITY') === 'stable') {
+          installCommands = [
+            ...installCommands,
+            `rm -f /etc/apt/sources.list.d/centreon*{unstable,testing}*`
+          ];
+        }
+      }
+
+      switch (Cypress.env('WEB_IMAGE_OS')) {
+        case 'alma8':
+          installCommands = [
+            ...installCommands,
+            `rm -f ${containerPackageDirectory}/centreon{,-central,-mariadb,-mysql}-${major_version}*.rpm`,
+            `dnf module reset -y php`,
+            `dnf module install -y php:remi-8.2`,
+            `dnf install -y ${containerPackageDirectory}/*.rpm`
+          ];
+          break;
+        case 'alma9':
+          installCommands = [
+            ...installCommands,
+            `rm -f ${containerPackageDirectory}/centreon{,-central,-mariadb,-mysql}-${major_version}*.rpm`,
+            `dnf module reset -y php`,
+            `dnf module enable -y php:8.2`,
+            `dnf install -y ${containerPackageDirectory}/*.rpm`
+          ];
+          break;
+        default:
+          installCommands = [
+            ...installCommands,
+            `rm -f ${containerPackageDirectory}/centreon{,-central,-mariadb,-mysql}_${major_version}*.deb`,
+            `apt-get update`,
+            `apt-get install -o Dpkg::Options::="--force-confdef" -o Dpkg::Options::="--force-confold" -y ${containerPackageDirectory}/centreon-*.deb`
+          ];
       }
 
       return cy.execInContainer({
-        command: [
-          `rm -f /tmp/packages-update-centreon/centreon{,-central,-mariadb,-mysql}_${major_version}*.deb`,
-          'apt-get update',
-          'apt-get install -y /tmp/packages-update-centreon/centreon-*.deb'
-        ],
+        command: installCommands,
         name: 'web'
       });
     })
@@ -275,6 +414,7 @@ const checkPlatformVersion = (platformVersion: string): Cypress.Chainable => {
       if (isExpected) {
         return null;
       }
+
       throw new Error(
         `The platform version is not the correct one (expected: ${platformVersion}, actual: ${output}).`
       );
@@ -301,56 +441,115 @@ const insertResources = (): Cypress.Chainable => {
   return cy.wrap(Promise.all(files.map(insertFixture)));
 };
 
+const prepareUpdateFileForUpgrade = (): Cypress.Chainable => {
+  return cy.getWebVersion().then(({ major_version, minor_version }) => {
+    const targetUpdateFile = `/usr/share/centreon/www/install/php/Update-${major_version}.${minor_version}.php`;
+
+    // Check if the version-specific file already exists
+    return cy.execInContainer({
+      command: `ls ${targetUpdateFile} || echo "File not found"`,
+      name: 'web'
+    }).then((fileCheckResult) => {
+      // If version-specific file already exists, no action needed
+      if (!fileCheckResult.output.includes("File not found")) {
+        cy.log(`Version-specific update file already exists in container: ${targetUpdateFile}`);
+        return cy.wrap(null);
+      }
+
+      // If version-specific file does not exist => copy content from Update-next.php
+      return cy.exec(`ls ../../www/install/php/Update-next.php || echo ""`)
+      .then((result) => {
+        const updateNextFile = result.stdout.trim();
+        if (!updateNextFile) {
+          cy.log("Update-next.php file not found");
+          return cy.wrap(null);
+        }
+
+        // Copy the Update-next.php content to container with proper name
+        return cy.copyToContainer({
+          source: updateNextFile,
+          destination: targetUpdateFile,
+          type: CopyToContainerContentType.File
+        })
+        .then(() => {
+          // Check if file was copied successfully
+          return cy.execInContainer({
+            command: `ls -la ${targetUpdateFile} || echo "File not found after copy"`,
+            name: 'web'
+          }).then((lsResult) => {
+
+            if (lsResult.output.includes("File not found")) {
+              cy.log("WARNING: Copy operation did not create the target file");
+              return cy.wrap(null);
+            }
+
+            // Change version in the file
+            return cy.execInContainer({
+              command: `sed -i "s/version = '';/version = '${major_version}.${minor_version}';/g" ${targetUpdateFile}`,
+              name: 'web'
+            });
+          });
+        });
+      });
+    });
+  });
+};
+
 When('administrator updates packages to current version', () => {
   updatePlatformPackages();
 });
 
 When('administrator runs the update procedure', () => {
-  cy.visit('/');
+  prepareUpdateFileForUpgrade()
+  .then(() => {
+    cy.visit('/');
 
-  cy.wait('@getStep1').then(() => {
-    cy.get('.btc.bt_info').should('be.visible').click();
-  });
-
-  cy.wait('@getStep2').then(() => {
-    cy.get('span[style]').each(($span) => {
-      cy.wrap($span).should('have.text', 'Loaded');
+    cy.wait('@getStep1', { timeout: 60000 }).then(() => {
+      cy.get('.btc.bt_info').should('be.visible').click();
     });
-    cy.get('.btc.bt_info').should('be.visible').click();
-  });
-
-  cy.wait('@getStep3');
-  cy.contains('Release notes');
-  // check correct updated version
-  const installed_version = Cypress.env('installed_version');
-  cy.log(`installed_version : ${installed_version}`);
-  cy.getWebVersion().then(({ major_version, minor_version }) => {
-    cy.contains(
-      `upgraded from version ${installed_version} to ${major_version}.${minor_version}`
-    ).should('be.visible');
-  });
-  cy.get('#next', { timeout: 15000 }).should('not.be.enabled');
-  // button is disabled during 3s in order to read documentation
-  cy.get('#next', { timeout: 15000 }).should('be.enabled').click();
-
-  cy.wait('@generatingCache')
-    .get('span[style]', { timeout: 15000 })
-    .each(($span) => {
-      cy.wrap($span).should('have.text', 'OK');
+    cy.wait('@getStep2',{ timeout: 60000 }).then(() => {
+      cy.get('span[style]').each(($span) => {
+        cy.wrap($span).should('have.text', 'Loaded');
+      });
+      cy.get('.btc.bt_info').should('be.visible').click();
     });
-  cy.get('.btc.bt_info', { timeout: 15000 }).should('be.visible').click();
 
-  cy.wait('@getStep5');
-  cy.contains('Congratulations');
+    cy.wait('@getStep3');
+    cy.contains('Release notes');
+    // check correct updated version
+    const installed_version = Cypress.env('installed_version');
+    cy.log(`installed_version : ${installed_version}`);
 
-  // disable statistics if checkbox is available (only on upgrade to new major version)
-  cy.get('body').then(($body) => {
-    if ($body.find('#send_statistics').length) {
-      cy.get('#send_statistics').uncheck({ force: true });
+    if (['testing', 'stable'].includes(Cypress.env('STABILITY'))) {
+      cy.getWebVersion().then(({ major_version, minor_version }) => {
+        cy.contains(
+          `upgraded from version ${installed_version} to ${major_version}.${minor_version}`
+        ).should('be.visible');
+      });
     }
-  });
 
-  cy.get('.btc.bt_success').should('be.visible').click();
+    // button is disabled during 3s in order to read documentation
+    cy.get('#next', { timeout: 15000 }).should('be.enabled').click();
+
+    cy.wait('@generatingCache')
+      .get('span[style]', { timeout: 15000 })
+      .each(($span) => {
+        cy.wrap($span).should('have.text', 'OK');
+      });
+    cy.get('.btc.bt_info', { timeout: 15000 }).should('be.visible').click();
+
+    cy.wait('@getStep5');
+    cy.contains('Congratulations');
+
+    // disable statistics if checkbox is available (only on upgrade to new major version)
+    cy.get('body').then(($body) => {
+      if ($body.find('#send_statistics').length) {
+        cy.get('#send_statistics').uncheck({ force: true });
+      }
+    });
+
+    cy.get('.btc.bt_success').should('be.visible').click();
+  });
 });
 
 Then(
@@ -381,9 +580,11 @@ Then(
       })
       .applyPollerConfiguration();
     cy.visit('/');
-    cy.getWebVersion().then(({ major_version, minor_version }) => {
-      cy.contains(`${major_version}.${minor_version}`).should('be.visible');
-    });
+    if (['testing', 'stable'].includes(Cypress.env('STABILITY'))) {
+      cy.getWebVersion().then(({ major_version, minor_version }) => {
+        cy.contains(`${major_version}.${minor_version}`).should('be.visible');
+      });
+    }
     cy.loginByTypeOfUser({
       jsonName: 'admin'
     }).wait('@getLastestUserFilters');
@@ -458,6 +659,8 @@ Then('Poller configuration should be fully generated', () => {
 });
 
 export {
+  localPackageDirectory,
+  containerPackageDirectory,
   getCentreonPreviousMajorVersion,
   getCentreonStableMinorVersions,
   installCentreon,
