@@ -198,6 +198,7 @@ class CentreonGraph
 
         $DBRESULT = $this->DBC->query("SELECT RRDdatabase_path, RRDdatabase_status_path FROM config LIMIT 1");
         $config = $DBRESULT->fetch();
+
         $this->dbPath = $config["RRDdatabase_path"];
         $this->dbStatusPath = $config['RRDdatabase_status_path'];
         unset($config);
@@ -495,9 +496,9 @@ class CentreonGraph
 
             $DBRESULT = $this->DBC->prepare($query);
             if (isset($this->metricsEnabled) && count($this->metricsEnabled) > 0) {
-                $DBRESULT->bindValue(':l_rselector', $l_rselector);
+                $DBRESULT->bindParam(':l_rselector', $l_rselector);
             } else {
-                $DBRESULT->bindValue(':index_id', $this->index);
+                $DBRESULT->bindParam(':index_id', $this->index);
             }
 
             $DBRESULT->execute();
@@ -527,9 +528,9 @@ class CentreonGraph
 
             $DBRESULT = $this->DB->prepare($query);
             if (isset($this->metricsEnabled) && count($this->metricsEnabled) > 0) {
-                $DBRESULT->bindValue(':l_vselector', $l_vselector);
+                $DBRESULT->bindParam(':l_vselector', $l_vselector);
             } else {
-                $DBRESULT->bindValue(':index_id', $this->index);
+                $DBRESULT->bindParam(':index_id', $this->index);
             }
 
             $DBRESULT->execute();
@@ -1247,7 +1248,7 @@ class CentreonGraph
 
         $this->log("index_data for " . $svc_instance);
         $DBRESULT = $this->DBC->prepare("SELECT * FROM index_data WHERE id = :svc_instance LIMIT 1");
-        $DBRESULT->bindValue(':svc_instance', $svc_instance, PDO::PARAM_INT);
+        $DBRESULT->bindParam(':svc_instance', $svc_instance, PDO::PARAM_INT);
         $DBRESULT->execute();
 
         if ($DBRESULT->rowCount()) {
@@ -1257,7 +1258,7 @@ class CentreonGraph
              */
             if (preg_match("/meta_([0-9]*)/", $this->indexData["service_description"], $matches)) {
                 $DBRESULT_meta = $this->DB->prepare("SELECT meta_name FROM meta_service WHERE `meta_id` = :meta_id");
-                $DBRESULT_meta->bindValue(':meta_id', $matches[1], PDO::PARAM_INT);
+                $DBRESULT_meta->bindParam(':meta_id', $matches[1], PDO::PARAM_INT);
                 $DBRESULT_meta->execute();
 
                 $meta = $DBRESULT_meta->fetch();
@@ -1561,13 +1562,13 @@ class CentreonGraph
             $DBRESULT = $this->DB->prepare(
                 "SELECT metric_id, rnd_color FROM `ods_view_details` WHERE `index_id` = :index_id"
             );
-            $DBRESULT->bindValue(':index_id', $this->index, PDO::PARAM_INT);
+            $DBRESULT->bindParam(':index_id', $this->index, PDO::PARAM_INT);
             $DBRESULT->execute();
             while (($row = $DBRESULT->fetch(PDO::FETCH_ASSOC))) {
                 $this->colorCache[$row['metric_id']] = $row['rnd_color'];
             }
         }
-        
+
         if (isset($this->colorCache[$metricId]) && preg_match("/^\#[a-f0-9]{6,6}/i", $this->colorCache[$metricId])) {
             return $this->colorCache[$metricId];
         }
@@ -1630,7 +1631,7 @@ class CentreonGraph
             '#ff66ff', '#ff9900', '#ff9933', '#ff9966', '#ff9999', '#ff99cc',
             '#ff99ff', '#ffcc00', '#ffcc33', '#ffcc66', '#ffcc99', '#ffcccc',
             '#ffccff');
-            return $webSafeColors[rand(0, sizeof($webSafeColors) - 1)];
+        return $webSafeColors[rand(0, sizeof($webSafeColors) - 1)];
     }
 
     /**
@@ -1947,8 +1948,8 @@ class CentreonGraph
     {
         $sql = "SELECT id FROM index_data WHERE host_id = :host_id AND service_id = :service_id";
         $res = $this->DBC->prepare($sql);
-        $res->bindValue(':host_id', $hostId, PDO::PARAM_INT);
-        $res->bindValue(':service_id', $serviceId, PDO::PARAM_INT);
+        $res->bindParam(':host_id', $hostId, PDO::PARAM_INT);
+        $res->bindParam(':service_id', $serviceId, PDO::PARAM_INT);
         $res->execute();
 
         if ($res->rowCount()) {
