@@ -533,6 +533,10 @@ describe('column sorting', () => {
       });
 
       cy.contains('notification1').should('exist');
+
+      cy.makeSnapshot(
+        `column sorting --  executes a listing request when the ${label} column is clicked`
+      );
     });
   });
 });
