@@ -68,12 +68,13 @@ const DisacknowledgeForm = ({
     setDisacknowledgeAttachedResources(Boolean(event.target.checked));
   };
 
-  const hasHosts = resources.find(propEq('type', 'host'));
+  const hasHosts = resources.find(propEq('host', 'type'));
 
   return (
     <Dialog
       open
       confirmDisabled={sendingDisacknowledgeResources}
+      data-testid="modalDisacknowledge"
       labelCancel={t(labelCancel)}
       labelConfirm={t(labelDisacknowledge)}
       labelTitle={t(labelDisacknowledge)}
