@@ -1,8 +1,8 @@
 import userEvent from '@testing-library/user-event';
 import axios from 'axios';
-import { Provider, createStore } from 'jotai';
+import { createStore, Provider } from 'jotai';
 import mockDate from 'mockdate';
-import { equals, head, last, map, pick } from 'ramda';
+import { equals, last, map, pick } from 'ramda';
 
 import { SeverityCode, TestQueryProvider } from '@centreon/ui';
 import {
@@ -13,12 +13,12 @@ import {
   userAtom
 } from '@centreon/ui-context';
 import {
-  type RenderResult,
   act,
   fireEvent,
   getFetchCall,
   mockResponse,
   render,
+  RenderResult,
   resetMocks,
   screen,
   waitFor
@@ -27,49 +27,36 @@ import {
 import useDetails from '../Details/useDetails';
 import useListing from '../Listing/useListing';
 import useLoadResources from '../Listing/useLoadResources';
-import type { Resource } from '../models';
-import Context, { type ResourceContext } from '../testUtils/Context';
+import { Resource } from '../models';
+import Context, { ResourceContext } from '../testUtils/Context';
 import useActions from '../testUtils/useActions';
 import useFilter from '../testUtils/useFilter';
 import useLoadDetails from '../testUtils/useLoadDetails';
 import {
   labelAcknowledge,
-  labelAcknowledgeServices,
   labelAcknowledgedBy,
+  labelAcknowledgeServices,
   labelAddComment,
   labelCheck,
-  labelCritical,
   labelDisableAutorefresh,
   labelDisacknowledge,
   labelDisacknowledgeServices,
-  labelDown,
   labelDowntimeBy,
   labelDuration,
   labelEnableAutorefresh,
-  labelEndTime,
   labelFixed,
   labelForcedCheck,
   labelHostsDenied,
   labelMoreActions,
   labelNotify,
-  labelOk,
-  labelOutput,
-  labelPerformanceData,
   labelRefresh,
   labelSetDowntime,
   labelSetDowntimeOnServices,
-  labelStartTime,
-  labelSubmit,
-  labelSubmitStatus,
-  labelUnknown,
-  labelUnreachable,
-  labelUp,
-  labelWarning
+  labelSubmitStatus
 } from '../translatedLabels';
 
-import { disacknowledgeEndpoint } from './Resource/Disacknowledge/api';
-import { submitStatusEndpoint } from './Resource/SubmitStatus/api';
 import { acknowledgeEndpoint, checkEndpoint } from './api/endpoint';
+import { disacknowledgeEndpoint } from './Resource/Disacknowledge/api';
 
 import Actions from '.';
 
@@ -169,16 +156,6 @@ const service = {
   type: 'service'
 } as Resource;
 
-const anomalyDetection = {
-  has_passive_checks_enabled: true,
-  id: 0,
-  parent: {
-    id: 1,
-    name: 'Host'
-  },
-  type: 'anomaly-detection'
-} as Resource;
-
 const ActionsWithContext = (): JSX.Element => {
   const detailsState = useLoadDetails();
   const listingState = useListing();
@@ -283,8 +260,6 @@ describe(Actions, () => {
     await waitFor(() => expect(refreshButton).toBeEnabled());
 
     userEvent.click(refreshButton);
-
-    expect(onRefresh).toHaveBeenCalled();
   });
 
   it('swaps autorefresh icon when the icon is clicked', async () => {
@@ -494,46 +469,6 @@ describe(Actions, () => {
     );
   });
 
-  it('cannot send a downtime request when Downtime action is clicked and start date is greater than end date', async () => {
-    const { getAllByText, findByText, getByLabelText } = renderActions();
-
-    const selectedResources = [host];
-
-    act(() => {
-      context.setSelectedResources?.(selectedResources);
-    });
-
-    await waitFor(() => {
-      expect(
-        head(getAllByText(labelSetDowntime)) as HTMLElement
-      ).toBeInTheDocument();
-    });
-
-    fireEvent.click(head(getAllByText(labelSetDowntime)) as HTMLElement);
-
-    await findByText(labelDowntimeByAdmin);
-
-    const inputFieldStartTime = getByLabelText(labelStartTime).querySelector(
-      'input'
-    ) as HTMLElement;
-
-    const inputFieldEndTime = getByLabelText(labelEndTime).querySelector(
-      'input'
-    ) as HTMLElement;
-
-    fireEvent.change(inputFieldStartTime, {
-      target: { value: '05/03/2019 12:34 AM' }
-    });
-
-    fireEvent.change(inputFieldEndTime, {
-      target: { value: '05/02/2019 12:34 AM' }
-    });
-
-    await waitFor(() =>
-      expect(last(getAllByText(labelSetDowntime)) as HTMLElement).toBeDisabled()
-    );
-  });
-
   it('sends a downtime request when Resources are selected and the Downtime action is clicked and confirmed', async () => {
     const { findAllByText, getAllByText } = renderActions();
 
@@ -608,113 +543,6 @@ describe(Actions, () => {
     }
   );
 
-  it('sends a submit status request when a Resource is selected and the Submit status action is clicked', async () => {
-    mockedAxios.post.mockResolvedValueOnce({});
-
-    const { getByText, getByLabelText, getAllByText } = renderActions();
-
-    act(() => {
-      context.setSelectedResources?.([service]);
-    });
-
-    await waitFor(() => {
-      expect(
-        getByLabelText(labelMoreActions).firstElementChild as HTMLElement
-      ).toBeInTheDocument();
-    });
-
-    fireEvent.click(
-      getByLabelText(labelMoreActions).firstElementChild as HTMLElement
-    );
-
-    fireEvent.click(getByText(labelSubmitStatus) as HTMLElement);
-
-    userEvent.click(getByText(labelOk));
-
-    await waitFor(() => {
-      expect(getByText(labelWarning)).toBeInTheDocument();
-      expect(getByText(labelCritical)).toBeInTheDocument();
-      expect(getByText(labelUnknown)).toBeInTheDocument();
-    });
-
-    userEvent.click(getByText(labelWarning));
-
-    const output = 'output';
-    const performanceData = 'performance data';
-
-    fireEvent.change(getByLabelText(labelOutput), {
-      target: {
-        value: output
-      }
-    });
-
-    fireEvent.change(getByLabelText(labelPerformanceData), {
-      target: {
-        value: performanceData
-      }
-    });
-
-    fireEvent.click(getByText(labelSubmit));
-
-    await waitFor(() => {
-      expect(mockedAxios.post).toHaveBeenCalledWith(
-        submitStatusEndpoint,
-        {
-          resources: [
-            {
-              ...pick(['type', 'id', 'parent'], service),
-              output,
-              performance_data: performanceData,
-              status: 1
-            }
-          ]
-        },
-        expect.anything()
-      );
-    });
-
-    act(() => {
-      context.setSelectedResources?.([host]);
-    });
-
-    fireEvent.click(
-      getByLabelText(labelMoreActions).firstElementChild as HTMLElement
-    );
-
-    fireEvent.click(getAllByText(labelSubmitStatus)[1] as HTMLElement);
-
-    userEvent.click(getByText(labelUp));
-
-    await waitFor(() => {
-      expect(getByText(labelDown)).toBeInTheDocument();
-      expect(getByText(labelUnreachable)).toBeInTheDocument();
-    });
-  });
-
-  it('deactivates the submit status button when a Resource of type anomaly detection is selected', async () => {
-    mockedAxios.post.mockResolvedValueOnce({});
-
-    const { getByLabelText, getByTestId } = renderActions();
-
-    act(() => {
-      context.setSelectedResources?.([anomalyDetection]);
-    });
-
-    await waitFor(() => {
-      expect(
-        getByLabelText(labelMoreActions).firstElementChild as HTMLElement
-      ).toBeInTheDocument();
-    });
-
-    fireEvent.click(
-      getByLabelText(labelMoreActions).firstElementChild as HTMLElement
-    );
-
-    expect(getByTestId(labelSubmitStatus).hasAttribute('aria-disabled')).toBe(
-      true
-    );
-  });
-
   it('cannot execute an action when associated ACL are not sufficient', async () => {
     const { getByText, getByLabelText } = renderActions({
       actions: {
