@@ -1,22 +1,23 @@
+import { makeStyles } from 'tss-react/mui';
+
 import { styled } from '@mui/material';
-import { makeStyles } from '@mui/styles';
 
 import { LoadingSkeleton } from '@centreon/ui';
 
-const useStyles = makeStyles((theme) => ({
+const useStyles = makeStyles()((theme) => ({
   loadingSkeleton: {
     display: 'grid',
     gridTemplateRows: 'repeat(3, 67px)',
-    rowGap: theme.spacing(2),
-  },
+    rowGap: theme.spacing(2)
+  }
 }));
 
 const ContactsSkeleton = styled(LoadingSkeleton)(() => ({
-  transform: 'none',
+  transform: 'none'
 }));
 
 const ContactsLoadingSkeleton = (): JSX.Element => {
-  const classes = useStyles();
+  const { classes } = useStyles();
 
   return (
     <div className={classes.loadingSkeleton}>
