@@ -8,12 +8,14 @@ import {
 
 import { useAtomValue } from 'jotai';
 import {
+  add,
   equals,
   find,
   head,
   isEmpty,
   isNil,
   map,
+  negate,
   not,
   or,
   pipe,
@@ -30,15 +32,19 @@ import { Skeleton, Typography } from '@mui/material';
 
 import {
   getData,
-  ParentSize,
   timeFormat,
   useLocaleDateTimeFormat,
-  useRequest
+  useRequest,
+  ParentSize
 } from '@centreon/ui';
 
 import { CommentParameters } from '../../Actions/api';
 import { selectedResourcesDetailsAtom } from '../../Details/detailsAtoms';
 import { ResourceDetails } from '../../Details/models';
+import {
+  CustomTimePeriod,
+  CustomTimePeriodProperty
+} from '../../Details/tabs/Graph/models';
 import { TimelineEvent } from '../../Details/tabs/Timeline/models';
 import { Resource } from '../../models';
 import { labelNoDataForThisPeriod } from '../../translatedLabels';
@@ -48,10 +54,12 @@ import {
   isListingGraphOpenAtom,
   timeValueAtom
 } from './Graph/mouseTimeValueAtoms';
+import { TimeShiftDirection } from './Graph/TimeShiftZones';
 import Legend from './Legend';
 import LoadingSkeleton from './LoadingSkeleton';
 import {
   AdditionalLines,
+  AdjustTimePeriodProps,
   FilterLines,
   GraphData,
   Line as LineModel,
@@ -61,11 +69,11 @@ import {
 import { getLineData, getMetrics, getTimeSeries } from './timeSeries';
 
 interface Props {
-  canAdjustTimePeriod?: boolean;
+  adjustTimePeriod?: (props: AdjustTimePeriodProps) => void;
+  customTimePeriod?: CustomTimePeriod;
   displayCompleteGraph?: () => void;
   displayEventAnnotations?: boolean;
   displayTitle?: boolean;
-  end: string;
   endpoint?: string;
   filterLines?: ({ lines, resource }: FilterLines) => NewLines;
   getPerformanceGraphRef?: (
@@ -79,7 +87,7 @@ interface Props {
   onAddComment?: (commentParameters: CommentParameters) => void;
   renderAdditionalLines?: (args: AdditionalLines) => ReactNode;
   resource: Resource | ResourceDetails;
-  start: string;
+  resourceDetailsUpdated?: boolean;
   timeline?: Array<TimelineEvent>;
   toggableLegend?: boolean;
   xAxisTickFormat?: string;
@@ -137,6 +145,8 @@ const useStyles = makeStyles<MakeStylesProps>()(
   })
 );
 
+const shiftRatio = 2;
+
 const PerformanceGraph = <T,>({
   endpoint,
   graphHeight,
@@ -145,7 +155,9 @@ const PerformanceGraph = <T,>({
   timeline,
   resource,
   onAddComment,
-  canAdjustTimePeriod = false,
+  adjustTimePeriod,
+  customTimePeriod,
+  resourceDetailsUpdated = true,
   displayEventAnnotations = false,
   displayTitle = true,
   limitLegendRows,
@@ -155,12 +167,10 @@ const PerformanceGraph = <T,>({
   graphActions,
   getPerformanceGraphRef,
   renderAdditionalLines,
-  end,
-  start,
   filterLines
 }: Props): JSX.Element => {
   const { classes } = useStyles({
-    canAdjustTimePeriod,
+    canAdjustTimePeriod: not(isNil(adjustTimePeriod)),
     displayTitle,
     graphHeight
   });
@@ -206,7 +216,7 @@ const PerformanceGraph = <T,>({
             newLineData.map((line) => ({
               ...line,
               display:
-                find(propEq('name', line.name), lineData)?.display ?? true
+                find(propEq(line.name, 'name'), lineData)?.display ?? true
             }))
           );
 
@@ -268,14 +278,15 @@ const PerformanceGraph = <T,>({
     );
   }
 
-  const getLineByMetric = (metric): LineModel =>
-    find(propEq('metric', metric), lineData) as LineModel;
+  const getLineByMetric = (metric): LineModel => {
+    return find(propEq(metric, 'metric'), lineData) as LineModel;
+  };
 
   const toggleMetricLine = (metric): void => {
     const line = getLineByMetric(metric);
 
     setLineData([
-      ...reject(propEq('metric', metric), lineData),
+      ...reject(propEq(metric, 'metric'), lineData),
       { ...line, display: !line.display }
     ]);
   };
@@ -284,7 +295,7 @@ const PerformanceGraph = <T,>({
     const fadedLines = map((line) => ({ ...line, highlight: false }), lineData);
 
     setLineData([
-      ...reject(propEq('metric', metric), fadedLines),
+      ...reject(propEq(metric, 'metric'), fadedLines),
       { ...getLineByMetric(metric), highlight: true }
     ]);
   };
@@ -301,7 +312,7 @@ const PerformanceGraph = <T,>({
   const sortedLines =
     filtredLines?.newSortedLines ?? sortBy(prop('name'), lineData);
   const displayedLines =
-    filtredLines?.newLines ?? reject(propEq('display', false), sortedLines);
+    filtredLines?.newLines ?? reject(propEq(false, 'display'), sortedLines);
 
   const selectMetricLine = (metric: string): void => {
     const metricLine = getLineByMetric(metric);
@@ -334,6 +345,39 @@ const PerformanceGraph = <T,>({
     );
   };
 
+  const getShiftedDate = ({ property, direction, timePeriod }): Date => {
+    const adjustTimePeriodProps =
+      (timePeriod.end.getTime() - timePeriod.start.getTime()) / shiftRatio;
+
+    return new Date(
+      add(
+        prop(property, timePeriod).getTime(),
+        equals(direction, TimeShiftDirection.backward)
+          ? negate(adjustTimePeriodProps)
+          : adjustTimePeriodProps
+      )
+    );
+  };
+
+  const shiftTime = (direction: TimeShiftDirection): void => {
+    if (isNil(customTimePeriod)) {
+      return;
+    }
+
+    adjustTimePeriod?.({
+      end: getShiftedDate({
+        direction,
+        property: CustomTimePeriodProperty.end,
+        timePeriod: customTimePeriod
+      }),
+      start: getShiftedDate({
+        direction,
+        property: CustomTimePeriodProperty.start,
+        timePeriod: customTimePeriod
+      })
+    });
+  };
+
   const timeTick = propOr<string, TimeValue | null, string>(
     '',
     'timeTick',
@@ -378,19 +422,21 @@ const PerformanceGraph = <T,>({
         <ParentSize>
           {({ width, height }): JSX.Element => (
             <Graph<T>
+              applyZoom={adjustTimePeriod}
               base={base as number}
-              canAdjustTimePeriod={canAdjustTimePeriod}
+              canAdjustTimePeriod={not(isNil(adjustTimePeriod))}
               containsMetrics={containsMetrics}
               displayEventAnnotations={displayEventAnnotations}
               displayTimeValues={displayTimeValues}
-              end={end}
               height={height}
               interactWithGraph={interactWithGraph}
               lines={displayedLines}
-              loading={sendingGetGraphDataRequest}
+              loading={
+                not(resourceDetailsUpdated) && sendingGetGraphDataRequest
+              }
               renderAdditionalLines={renderAdditionalLines}
               resource={resource}
-              start={start}
+              shiftTime={shiftTime}
               timeSeries={timeSeries}
               timeline={timeline}
               width={width}
