@@ -8,7 +8,12 @@ import IconColumn from './IconColumn';
 
 const ChecksColumn = ({ row }: ComponentColumnProps): JSX.Element | null => {
   const icon = (
-    <ChecksIcon {...pick(['active_checks', 'passive_checks'], row)} />
+    <ChecksIcon
+      {...pick(
+        ['has_active_checks_enabled', 'has_passive_checks_enabled'],
+        row
+      )}
+    />
   );
 
   return <IconColumn>{icon}</IconColumn>;
