@@ -1,39 +1,27 @@
 <?php
 
 /*
- * Copyright 2005-2021 Centreon
- * Centreon is developed by : Julien Mathis and Romain Le Merlus under
- * GPL Licence 2.0.
+ * Copyright 2005 - 2025 Centreon (https://www.centreon.com/)
  *
- * This program is free software; you can redistribute it and/or modify it under
- * the terms of the GNU General Public License as published by the Free Software
- * Foundation ; either version 2 of the License.
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
  *
- * This program is distributed in the hope that it will be useful, but WITHOUT ANY
- * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
- * PARTICULAR PURPOSE. See the GNU General Public License for more details.
+ * https://www.apache.org/licenses/LICENSE-2.0
  *
- * You should have received a copy of the GNU General Public License along with
- * this program; if not, see <http://www.gnu.org/licenses>.
- *
- * Linking this program statically or dynamically with other modules is making a
- * combined work based on this program. Thus, the terms and conditions of the GNU
- * General Public License cover the whole combination.
- *
- * As a special exception, the copyright holders of this program give Centreon
- * permission to link this program with independent modules to produce an executable,
- * regardless of the license terms of these independent modules, and to copy and
- * distribute the resulting executable under terms of Centreon choice, provided that
- * Centreon also meet, for each linked independent module, the terms  and conditions
- * of the license of that module. An independent module is a module which is not
- * derived from this program. If you modify this program, you may extend this
- * exception to your version of the program, but you are not obliged to do so. If you
- * do not wish to do so, delete this exception statement from your version.
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  *
  * For more information : contact@centreon.com
  *
  */
 
+use Adaptation\Database\Connection\Collection\QueryParameters;
+use Adaptation\Database\Connection\ValueObject\QueryParameter;
+
 if (!isset($centreon)) {
     exit();
 }
@@ -810,12 +798,10 @@ function updateContactHostCommands($contactId = null, $fields = [])
     }
 
     try {
-        $query = "DELETE FROM contact_hostcommands_relation WHERE contact_contact_id = :contact_id";
-        $successDelete = $pearDB->executePreparedQuery($pearDB->prepare($query), ['contact_id' => $contactId]);
-
-        if (!$successDelete) {
-            return;
-        }
+        $pearDB->delete(
+            'DELETE FROM contact_hostcommands_relation WHERE contact_contact_id = :contact_id',
+            QueryParameters::create([QueryParameter::int('contact_id', $contactId)])
+        );
 
         $hostCommandIdsFromForm = $fields["contact_hostNotifCmds"] ?? $form->getSubmitValue("contact_hostNotifCmds");
 
@@ -824,14 +810,16 @@ function updateContactHostCommands($contactId = null, $fields = [])
         }
 
         $query = "INSERT INTO contact_hostcommands_relation(contact_contact_id, command_command_id) VALUES(:contact_id, :command_id)";
-        $pdoSth = $pearDB->prepareQuery($query);
         foreach ($hostCommandIdsFromForm as $hostCommandIdFromForm) {
-            $pearDB->executePreparedQuery(
-                $pdoSth,
-                ['contact_id' => $contactId, 'command_id' => (int)$hostCommandIdFromForm]
+            $pearDB->insert(
+                $query,
+                QueryParameters::create([
+                    QueryParameter::int('contact_id', $contactId),
+                    QueryParameter::int('command_id', (int)$hostCommandIdFromForm)
+                ])
             );
         }
-    } catch (CentreonDbException $e) {
+    } catch (\Throwable $e) {
         CentreonLog::create()->error(
             CentreonLog::TYPE_SQL,
             "Error while updating the relationship between contacts and host commands",
@@ -1534,28 +1522,50 @@ function validatePasswordCreation(array $fields)
  * Validate password creation using defined security policy.
  *
  * @param array<string,mixed> $fields
- * @return mixed
+ *
+ * @return array<string,string>|true
  */
-function validatePasswordModification(array $fields)
+function validatePasswordModification(array $fields): array|bool
 {
-    global $pearDB;
-    $errors = [];
+    global $pearDB, $centreon;
+    $newPassword = $fields['contact_passwd'];
+    $confirmPassword = $fields['contact_passwd2'];
+    $currentPassword = $fields['current_password'];
+    $contactId = $fields['contact_id'];
 
-    if (empty($fields['contact_passwd'])) {
+    // If the user does not want to change his password, we do not need to check it
+    if (empty($newPassword) && empty($confirmPassword) && empty($currentPassword)) {
         return true;
     }
 
-    $password = $fields['contact_passwd'];
-    $contactId = $fields['contact_id'];
-
-    try {
-        $contact = new \CentreonContact($pearDB);
-        $contact->respectPasswordPolicyOrFail($password, $contactId);
-    } catch (\Throwable $e) {
-        $errors['contact_passwd'] = $e->getMessage();
+    // If the user only provided a confirmation password, he must provide a new password and a current password
+    if (empty($newPassword) && ! empty($confirmPassword) && empty($currentPassword)) {
+        return ['contact_passwd2' => _('Please fill in all password fields')];
     }
 
-    return count($errors) > 0 ? $errors : true;
+    // If the user only provided his current password, he must provide a new password
+    if (empty($newPassword) && ! empty($currentPassword)) {
+        return ['current_password' => _('Please fill in all password fields')];
+    }
+
+    // If the user wants to change his password, he must provide his current password
+    if (! empty($newPassword) && empty($currentPassword)) {
+        return ['current_password' => _('Please fill in all password fields')];
+    }
+
+    // If the user provided a current password, we check if it matches the one in the database
+    if (! empty($currentPassword) && password_verify($currentPassword, $centreon->user->passwd) === false) {
+        return ['current_password' => _('Authentication failed')];
+    }
+
+    try {
+        $contact = new CentreonContact($pearDB);
+        $contact->respectPasswordPolicyOrFail($newPassword, $contactId);
+
+        return true;
+    } catch (Throwable $e) {
+        return ['contact_passwd' => $e->getMessage()];
+    }
 }
 
 /**
@@ -1619,7 +1629,7 @@ function filterNonAdminFields(array $ret): array
         'contact_lang', 'default_page', 'contact_location', 'contact_autologin_key', 'contact_auth_type',
         'contact_acl_groups', 'contact_address1', 'contact_address2', 'contact_address3', 'contact_address4',
         'contact_address5', 'contact_address6', 'contact_comment', 'contact_register', 'contact_activate',
-        'contact_id', 'initialValues', 'centreon_token', 'contact_template_id', 'contact_type_msg'
+        'contact_id', 'initialValues', 'centreon_token', 'contact_template_id', 'contact_type_msg','contact_ldap_dn'
     ];
 
     foreach ($ret as $field => $value) {
