@@ -113,8 +113,9 @@ $form->addElement('text', 'sg_name', _("Name"), $attrsText);
 $form->addElement('text', 'sg_alias', _("Description"), $attrsText);
 
 $form->registerRule('validate_geo_coords', 'function', 'validateGeoCoords');
-$form->addElement('text', 'geo_coords', _("Geo coordinates"), $attrsText);
-$form->addRule('geo_coords', _("geo coords are not valid"), 'validate_geo_coords');
+$form->addElement('text', 'geo_coords', _('Geo coordinates'), $attrsText);
+$form->addRule('geo_coords', _('geo coords are not valid'), 'validate_geo_coords');
+$form->applyFilter('geo_coords', 'truncateGeoCoords');
 
 $form->addElement('header', 'relation', _("Relations"));
 
