@@ -39,7 +39,7 @@
 
 function myDecodeGroup($arg)
 {
-    $arg = html_entity_decode($arg, ENT_QUOTES, "UTF-8");
+    $arg = html_entity_decode($arg ?? '', ENT_QUOTES, "UTF-8");
     return ($arg);
 }
 
@@ -107,9 +107,9 @@ $form->setRequiredNote("<font style='color: red;'>*</font>&nbsp;" . _("Required
 ##End of form definition
 #
 
-# Smarty template Init
-$tpl = new Smarty();
-$tpl = initSmartyTpl($path, $tpl);
+// Smarty template initialization
+$tpl = SmartyBC::createSmartyTemplate($path);
+
 $tpl->assign(
     "helpattr",
     'TITLE, "' . _("Help") . '", CLOSEBTN, true, FIX, [this, 0, 5], BGCOLOR, "#ffff99", BORDERCOLOR, "orange", ' .
