@@ -35,7 +35,7 @@
  */
 
 if (!defined('SMARTY_DIR')) {
-    define('SMARTY_DIR', realpath('../vendor/' . SmartyCentreon::PACKAGE_CENTREON_SMARTY_NAME . '/libs/') . '/');
+    define('SMARTY_DIR', realpath('../vendor/smarty/smarty/libs/') . '/');
 }
 
 /*
@@ -62,7 +62,6 @@ require_once "$classdir/centreonLang.class.php";
 require_once "$classdir/centreonSession.class.php";
 require_once "$classdir/centreon.class.php";
 require_once "$classdir/centreonFeature.class.php";
-require_once SMARTY_DIR . "SmartyBC.class.php";
 
 /*
  * Create DB Connection
