@@ -120,15 +120,11 @@ if (!$is_admin && !$haveAccess) {
 } else {
     $tab_status = array();
 
+    $en = ["0" => _("No"), "1" => _("Yes")];
+
+    // Smarty template initialization
     $path = "./include/monitoring/objectDetails/";
-
-    $en = array("0" => _("No"), "1" => _("Yes"));
-
-    /*
-     * Smarty template Init
-     */
-    $tpl = new Smarty();
-    $tpl = initSmartyTpl($path, $tpl, "./template/");
+    $tpl = SmartyBC::createSmartyTemplate($path, './template/');
 
     // Get GMT
     $centreon->CentreonGMT->getMyGMTFromSession(session_id(), $pearDB);
